#
# spec file for package gstreamer
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define gst_branch 1.0

Name:           gstreamer
Version:        1.24.10
Release:        3.1
Summary:        Streaming-Media Framework Runtime
License:        LGPL-2.1-or-later
Group:          Productivity/Multimedia/Other
URL:            https://gstreamer.freedesktop.org
Source0:        %{url}/src/%{name}/%{name}-%{version}.tar.xz
Source1:        gstreamer.macros
Source2:        gstreamer.prov
Source99:       baselibs.conf

# PATCH-FEATURE-UPSTREAM gstreamer-rpm-prov.patch bgo#588784 dimstar@opensuse.org -- Add --rpm parameter to allow creation of rpm provides, patch from fedora
Patch1:         gstreamer-rpm-prov.patch
# PATCH-FIX-OPENSUSE gstreamer-pie.patch mgorse@suse.com -- create position-independent executables.
Patch2:         gstreamer-pie.patch

BuildRequires:  bison >= 2.4
BuildRequires:  check-devel
BuildRequires:  flex >= 2.5.31
BuildRequires:  gobject-introspection-devel >= 1.31.1
BuildRequires:  libcap-devel
BuildRequires:  libcap-progs
BuildRequires:  meson >= 1.1
BuildRequires:  pkgconfig
BuildRequires:  python3-base
BuildRequires:  python3-xml
BuildRequires:  rust >= 1.48
BuildRequires:  pkgconfig(bash-completion) >= 2.0
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(gio-unix-2.0)
BuildRequires:  pkgconfig(glib-2.0) >= 2.62.0
BuildRequires:  pkgconfig(gmodule-2.0)
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(libdw)
# Ensure that the documentation corresponds with the installed version:
Requires:       libgstreamer-1_0-0 = %{version}
# Core modules may depend on new enough libraries:
Requires:       libgstreamer-1_0-0 >= %{version}
Requires(pre):  permissions
# Generic name, never used in SuSE:
Provides:       gstreamer-doc = %{version}
%define libunwind_archs %{ix86} ia64 x86_64 %{arm} ppc ppc64 ppc64le aarch64 riscv64
%ifarch %{libunwind_archs}
BuildRequires:  pkgconfig(libunwind)
%endif

%description
GStreamer is a streaming-media framework, based on graphs of filters
which operate on media data. Applications using this library can do
anything from real-time sound processing to playing videos, and just
about anything else media-related.  Its plug-in-based architecture
means that new data types or processing capabilities can be added by
installing new plug-ins.

%package -n libgstreamer-1_0-0
Summary:        Streaming-Media Framework Runtime
# We want to have core modules installed:
Group:          System/Libraries
Requires:       %{name}

%description -n libgstreamer-1_0-0
GStreamer is a streaming-media framework, based on graphs of filters
which operate on media data. Applications using this library can do
anything from real-time sound processing to playing videos, and just
about anything else media-related.  Its plug-in-based architecture
means that new data types or processing capabilities can be added by
installing new plug-ins.

%package -n typelib-1_0-Gst-1_0
Summary:        Streaming-Media Framework Runtime -- Introspection bindings
Group:          System/Libraries

%description -n typelib-1_0-Gst-1_0
GStreamer is a streaming-media framework, based on graphs of filters
which operate on media data. Applications using this library can do
anything from real-time sound processing to playing videos, and just
about anything else media-related.  Its plug-in-based architecture
means that new data types or processing capabilities can be added by
installing new plug-ins.

This package provides the GObject Introspection bindings for GStreamer.

%package utils
Summary:        Streaming-Media Framework Runtime
# Generic name, never used in SuSE:
Group:          Productivity/Multimedia/Other
Provides:       gstreamer:%{_bindir}/gst-launch-%{gst_branch} = %{version}
# Symbol for unversioned wrappers:
Provides:       gstreamer-utils_versioned = %{version}

%description utils
GStreamer is a streaming-media framework, based on graphs of filters
which operate on media data. Applications using this library can do
anything from real-time sound processing to playing videos, and just
about anything else media-related.  Its plug-in-based architecture
means that new data types or processing capabilities can be added by
installing new plug-ins.

%package devel
Summary:        Include Files and Libraries mandatory for Development
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
# gstreamer-utils is required for the gstreamer-provides rpm magic.
Requires:       gstreamer-utils = %{version}
Requires:       libgstreamer-1_0-0 = %{version}
Requires:       typelib-1_0-Gst-1_0 = %{version}

%description devel
This package contains all necessary include files and libraries needed
to develop applications that require these.

%lang_package

%prep
%autosetup -p1
sed -i -e '1{s,^#!/usr/bin/env python3,#!%{_bindir}/python3,}' docs/gst-plugins-doc-cache-generator.py

%build
export PYTHON=%{_bindir}/python3
sed -i "s/'gst-plugin-scanner': /'gst-plugin-scanner-%{_target_cpu}': /" libs/gst/helpers/meson.build
grep "'gst-plugin-scanner-%{_target_cpu}': " libs/gst/helpers/meson.build || (echo "Couldn't set executable suffix in libs/gst/helpers/meson.build" ; exit 1)
sed -i "s/'gst-plugin-scanner'/'gst-plugin-scanner-%{_target_cpu}'/" meson.build
grep "'gst-plugin-scanner-%{_target_cpu}'" meson.build || (echo "Couldn't set executable suffix in meson.build" ; exit 1)
sed -i 's/"gst-plugin-scanner"/"gst-plugin-scanner-%{_target_cpu}"/' gst/gstpluginloader.c
grep '"gst-plugin-scanner-%{_target_cpu}"' gst/gstpluginloader.c || (echo "Couldn't set executable suffix in gst/gstpluginloader.c" ; exit 1)
# TODO: enable dbghelp
%meson \
	-Dptp-helper-permissions=capabilities \
	-Dpackage-name='openSUSE GStreamer package' \
	-Dpackage-origin='http://download.opensuse.org' \
	-Dintrospection=enabled \
	-Dbenchmarks=disabled \
	-Ddoc=disabled \
	-Dexamples=disabled \
	-Ddbghelp=disabled \
%ifnarch %{libunwind_archs}
	-Dlibunwind=disabled \
%endif
	%{nil}
%meson_build

# meson 0.61.4 in SLE 15 SP5 doesn't generate all variables needed in the pc files
# As a result the pkgconfig(...) provides are not generated in the rpm file so
# we have to add the variables to the pc files if they're missing
for pc in *-suse-linux/meson-private/*.pc ; do
   grep -q ^datarootdir= $pc || sed -ie "/^pluginsdir=.*/a datarootdir=\${prefix}\/share" $pc ;
   grep -q ^datadir= $pc || sed -ie "/^datarootdir=.*/a datadir=\${datarootdir}" $pc ;
   grep -q ^libexecdir= $pc || sed -ie "/^datadir=.*/a libexecdir=\${prefix}\/libexec" $pc ;
done

%install
%meson_install
%find_lang %{name}-%{gst_branch}
find %{buildroot} -type f -name "*.la" -delete -print
mkdir -p %{buildroot}%{_datadir}/gstreamer-%{gst_branch}/presets
# Install the rpm macros
install -m644 -D %{SOURCE1} %{buildroot}%{_fileattrsdir}/gstreamer.attr
install -m755 -D %{SOURCE2} %{buildroot}%{_rpmconfigdir}/gstreamer-provides

%if %{suse_version} >= 1600
%python3_fix_shebang_path %{buildroot}%{_libexecdir}/gstreamer-*/*
%endif

%verifyscript
%verify_permissions -e %{_libexecdir}/gstreamer-%{gst_branch}/gst-ptp-helper

%post
%set_permissions %{_libexecdir}/gstreamer-%{gst_branch}/gst-ptp-helper

%ldconfig_scriptlets -n libgstreamer-1_0-0

%files
%license COPYING
%dir %{_datadir}/gstreamer-%{gst_branch}
%dir %{_datadir}/gstreamer-%{gst_branch}/presets
%dir %{_libdir}/gstreamer-%{gst_branch}
%{_libdir}/gstreamer-%{gst_branch}/libgstcoreelements.so
%{_libdir}/gstreamer-%{gst_branch}/libgstcoretracers.so
%dir %{_libexecdir}/gstreamer-%{gst_branch}
%{_libexecdir}/gstreamer-%{gst_branch}/gst-completion-helper
%{_libexecdir}/gstreamer-%{gst_branch}/gst-plugin-scanner-%{_target_cpu}
%{_libexecdir}/gstreamer-%{gst_branch}/gst-hotdoc-plugins-scanner
%verify(not mode caps) %{_libexecdir}/gstreamer-%{gst_branch}/gst-ptp-helper
%{_datadir}/bash-completion/completions/
%{_datadir}/bash-completion/helpers/

%files -n libgstreamer-1_0-0
%{_libdir}/*.so.*

%files -n typelib-1_0-Gst-1_0
%{_libdir}/girepository-1.0/Gst-1.0.typelib
%{_libdir}/girepository-1.0/GstBase-1.0.typelib
%{_libdir}/girepository-1.0/GstCheck-1.0.typelib
%{_libdir}/girepository-1.0/GstController-1.0.typelib
%{_libdir}/girepository-1.0/GstNet-1.0.typelib

%files utils
%{_bindir}/*-%{gst_branch}
%{_mandir}/man?/*-%{gst_branch}*%{ext_man}

%files devel
%doc AUTHORS ChangeLog NEWS README.md RELEASE
%{_datadir}/aclocal/*.m4
# Own these directories to avoid build requirement on gdb
# only for directories ownership
%dir %{_datadir}/gdb
%dir %{_datadir}/gdb/auto-load
%dir %{_datadir}/gdb/auto-load%{_prefix}
%dir %{_datadir}/gdb/auto-load%{_libdir}
%{_datadir}/gdb/auto-load%{_libdir}/lib%{name}*.py
%dir %{_datadir}/gstreamer-%{gst_branch}/gdb
%{_datadir}/gstreamer-%{gst_branch}/gdb/glib_gobject_helper.py
%{_datadir}/gstreamer-%{gst_branch}/gdb/gst_gdb.py
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%{_libexecdir}/gstreamer-%{gst_branch}/gst-plugins-doc-cache-generator
%{_rpmconfigdir}/gstreamer-provides
%{_fileattrsdir}/gstreamer.attr
%{_datadir}/gir-1.0/*.gir

%files lang -f %{name}-%{gst_branch}.lang

%changelog
* Mon Dec  9 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.24.10:
  + Highlighted bugfixes:
  - More than 40 security fixes across a wide range of elements
    following an audit by the GitHub Security Lab, including the
    MP4, Matroska, Ogg and WAV demuxers, subtitle parsers, image
    decoders, audio decoders and the id3v2 tag parser.
  - avviddec: Fix regression that could trigger assertions about
    width/height mismatches.
  - appsink and appsrc fixes.
  - closed caption handling fixes.
  - decodebin3 and urisourcebin fixes.
  - glupload: dmabuf: Fix emulated tiled import.
  - level: fix LevelMeta values outside of the stated range.
  - mpegtsmux, flvmux: fix potential busy looping with high cpu
    usage in live mode.
  - pipeline dot file graph generation improvements.
  - qt(6): fix criticals with multiple qml(6)gl{src,sink}.
  - rtspsrc: Optionally timestamp RTP packets with their receive
    times in TCP/HTTP mode to enable clock drift handling.
  - splitmuxsrc: reduce number of file descriptors used.
  - systemclock: locking order fixes.
  - v4l2: fix possible v4l2videodec deadlock on shutdown; 8-bit
    bayer format fixes.
  - x265: Fix build with libx265 version >= 4.1 after
    masteringDisplayColorVolume API change.
  - macOS: fix rendering artifacts in retina displays, plus ptp
    clock fixes.
  - cargo: Default to thin lto for the release profile (for
    faster builds with lower memory requirements).
  - Various bug fixes, build fixes, memory leak fixes, and other
    stability and reliability improvements.
  - Updated translations.
  + gstreamer:
  - allocator: Avoid integer overflow when allocating sysmem and
    avoid integer overflow in qtdemux theora extension parsing
    (boo#1234449 CVE-2024-47606).
  - deviceprovider: fix leaking hidden providers.
  - gstreamer: prefix debug dot node names to prevent splitting.
  - pad: Never push sticky events in response to a FLUSH_STOP.
  - systemclock: Fix lock order violation and some cleanup.
  - utils: improve gst_util_ceil_log2().
  - ptp: use ip_mreq instead of ip_mreqn for macos.
  - tracers: unlock leaks tracer if already tracking.
* Tue Nov  5 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.24.9:
  + Highlighted bugfixes:
  - gst-rtsp-server security fix
  - GstAggregator start time selection and latency query fixes
    for force-live mode
  - audioconvert: fix dynamic handling of mix matrix, and accept
    custom upstream event for setting one
  - encodebin: fix parser selection for encoders that support
    multiple codecs
  - flvmux improvments for pipelines where timestamps don't start
    at 0
  - glcontext: egl: Unrestrict the support base DRM formats
  - kms: Add IMX-DCSS auto-detection in sink and fix stride with
    planar formats in allocator
  - macOS main application event loop fixes
  - mpegtsdemux: Handle PTS/DTS wraparound with ignore-pcr=true
  - playbin3, decodebin3, parsebin, urisourcebin: fix races, and
    improve stability and stream-collection handling
  - rtpmanager: fix early RTCP SR generation for sparse streams
    like metadata
  - qml6glsrc: Reduce capture delay
  - qtdemux: fix parsing of rotation matrix with 180 degree
    rotation
  - rtpav1depay: added wait-for-keyframe and request-keyframe
    properties
  - srt: make work with newer libsrt versions and don't
    re-connect on authentication failure
  - v4l2 fixes and improvement
  - webrtcsink, webrtcbin and whepsrc fixes
  - cerbero: fix Python 3.13 compatibility, g-i with newer
    setuptools, bootstrap on Arch Linux; iOS build fixes
  - Ship qroverlay plugin in binary packages
  - Various bug fixes, memory leak fixes, and other stability and
    reliability improvements
  + Gstreamer:
  - aggregator:
    . Fix start time selection first with force-live
    . Fix live query when force-live is TRUE
  - parse-launch: Make sure children are bins before recursing in
  - macos: Fix race conditions in cocoa/application main event
    loop
  - multiqueue: Do not unref the query we get in pad->query
* Mon Sep 23 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.24.8:
  + Highlighted bugfixes:
  - decodebin3: collection handling fixes
  - encodebin: Fix pad removal (and smart rendering in
    gst-editing-services)
  - glimagesink: Fix cannot resize viewport when video size
    changed in caps
  - matroskamux, webmmux: fix firefox compatibility issue with
    Opus audio streams
  - mpegtsmux: Wait for data on all pads before deciding on a
    best pad unless timing out
  - splitmuxsink: Override LATENCY query to pretend to downstream
    that we're not live
  - video: QoS event handling improvements
  - voamrwbenc: fix list of bitrates
  - vtenc: Restart encoding session when certain errors are
    detected
  - wayland: Fix ABI break in WL context type name
  - webrtcbin: Prevent crash when attempting to set answer on
    invalid SDP
  - cerbero: ship vp8/vp9 software encoders again, which went
    missing in 1.24.7; ship transcode plugin
  - Various bug fixes, memory leak fixes, and other stability and
    reliability improvements
  + gstreamer:
  - clock: Fix unchecked overflows in linear regression code
  - meta: Add missing include of gststructure.h
  - pad: Check data NULL-ness when probes are stopped
  - aggregator: Immediately return NONE from
    simple_get_next_time() on non-TIME segments
* Fri Aug 23 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.24.7:
  + Highlighted bugfixes:
  - Fix APE and Musepack audio file and GIF playback with FFmpeg
    7.0
  - playbin3: Fix potential deadlock with multiple playbin3s with
    glimagesink used in parallel
  - qt6: various qmlgl6src and qmlgl6sink fixes and improvements
  - rtspsrc: expose property to force usage of non-compliant
    setup URLs for RTSP servers where the automatic fallback
    doesn't work
  - urisourcebin: gapless playback and program switching fixes
  - v4l2: various fixes
  - va: Fix potential deadlock with multiple va elements used in
    parallel
  - meson: option to disable gst-full for static-library build
    configurations that do not need this
  - Various bug fixes, memory leak fixes, and other stability and
    reliability improvements
  + gstreamer:
  - bin: Don't keep the object lock while setting a GstContext
    when handling NEED_CONTEXT
  - core: Log pad name, not just the pointer
* Wed Jul 31 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.24.6:
  + Highlighted bugfixes:
  - Fix compatibility with FFmpeg 7.0.
  - qmlglsink: Fix failure to display content on recent Android
    devices.
  - adaptivedemux: Fix handling of closed caption streams.
  - cuda: Fix runtime compiler loading with old CUDA tookit.
  - decodebin3 stream selection handling fixes.
  - d3d11compositor, d3d12compositor: Fix transparent background
    mode with YUV output.
  - d3d12converter: Make gamma remap work as intended.
  - h264decoder: Update output frame duration for interlaced
    video when second field frame is discarded.
  - macOS audio device provider now listens to audio devices
    being added/removed at runtime.
  - Rust plugins: audioloudnorm, s3hlssink, gtk4paintablesink,
    livesync and webrtcsink fixes.
  - videoaggregator: preserve features in non-alpha caps for
    subclasses with non-system memory sink caps.
  - vtenc: Fix redistribute latency spam.
  - v4l2: fixes for complex video formats.
  - va: Fix strides when importing DMABUFs, dmabuf handle leaks,
    and blocklist unmaintained Intel i965 driver for encoding.
  - waylandsink: Fix surface cropping for rotated streams.
  - webrtcdsp: Enable multi_channel processing to fix handling of
    stereo streams.
  - Various bug fixes, memory leak fixes, and other stability and
    reliability improvements.
* Thu Jun 27 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.24.5:
  + Highlighted bugfixes:
  - webrtcsink: Support for AV1 via nvav1enc, av1enc or rav1enc
    encoders
  - AV1 RTP payloader/depayloader fixes to work correctly with
    Chrome and Pion WebRTC
  - av1parse, av1dec error handling/robustness improvements
  - av1enc: Handle force-keyunit events properly for WebRTC
  - decodebin3: selection and collection handling improvements
  - hlsdemux2: Various fixes for discontinuities, variant
    switching, playlist updates
  - qml6glsink: fix RGB format support
  - rtspsrc: more control URL handling fixes
  - v4l2src: Interpret V4L2 report of sync loss as video signal
    loss
  - d3d12 encoder, memory and videosink fixes
  - vtdec: more robust error handling, fix regression
  - ndi: support for NDI SDK v6
  - Various bug fixes, memory leak fixes, and other stability and
    reliability improvements
- Please see https://gstreamer.freedesktop.org/releases/1.24/ for
  changes between 1.24.0 and this version and even more in-depth
  info.
- Refresh patches with quilt.
- Drop 0001-Canonicalize-the-library-path-returned-by-dladdr.patch
  and 0001-ptp-Dont-install-test-executable.patch: Fixed upstream.
* Mon Apr 29 2024 pgajdos@suse.com
- remove dependency on /usr/bin/python3 using
  %%python3_fix_shebang_path macro, [bsc#1212476]
* Tue Mar 12 2024 Antonio Larrosa <alarrosa@suse.com>
- Replace the quick fix for boo#1221150 with the version submitted
  to upstream at
  https://gitlab.freedesktop.org/gstreamer/gstreamer/-/merge_requests/6322:
  * 0001-Canonicalize-the-library-path-returned-by-dladdr.patch
- Remove previous version of the fix for boo#1221150:
  * force-find-gst-plugin-scanner.patch
- Fix sed command to set the gst-plugin-scanner suffix correctly
- Add preventive checks for the sed commands that set the binary
  suffix so that they don't silently fail anymore.
* Mon Mar 11 2024 Antonio Larrosa <alarrosa@suse.com>
- Add patch from upstream to not install ptp-helper test executable
  * 0001-ptp-Dont-install-test-executable.patch
* Mon Mar 11 2024 Antonio Larrosa <alarrosa@suse.com>
- Add patch to remove the (wrong) check for relocated library which
  is making gstreamer fail to find the gst-plugin-scanner helper
  binary, thus using the installation path set at build time
  (boo#1221150):
  * force-find-gst-plugin-scanner.patch
* Tue Mar  5 2024 Antonio Larrosa <alarrosa@suse.com>
- Update to version 1.24.0:
  * Highlights
  - New Discourse forum and Matrix chat space
  - New Analytics and Machine Learning abstractions and elements
  - Playbin3 and decodebin3 are now stable and the default in
    gst-play-1.0, GstPlay/GstPlayer
  - The va plugin is now preferred over gst-vaapi and has higher
    ranks
  - GstMeta serialization/deserialization and other GstMeta
    improvements
  - New GstMeta for SMPTE ST-291M HANC/VANC Ancillary Data
  - New unixfd plugin for efficient 1:N inter-process
    communication on Linux
  - cudaipc source and sink for zero-copy CUDA memory sharing
    between processes
  - New intersink and intersrc elements for 1:N pipeline
    decoupling within the same process
  - Qt5 + Qt6 QML integration improvements including qml6glsrc,
    qml6glmixer, qml6gloverlay, and qml6d3d11sink elements
  - DRM Modifier Support for dmabufs on Linux
  - OpenGL, Vulkan and CUDA integration enhancements
  - Vulkan H.264 and H.265 video decoders
  - RTP stack improvements including new RFC7273 modes and more
    correct header extension handling in depayloaders
  - WebRTC improvements such as support for ICE consent
    freshness, and a new webrtcsrc element to complement
    webrtcsink
  - WebRTC signallers and webrtcsink implementations for LiveKit
    and AWS Kinesis Video Streams
  - WHIP server source and client sink, and a WHEP source
  - Precision Time Protocol (PTP) clock support for Windows and
    other additions
  - Low-Latency HLS (LL-HLS) support and many other HLS and DASH
    enhancements
  - New W3C Media Source Extensions library
  - Countless closed caption handling improvements including new
    cea608mux and cea608tocea708 elements
  - Translation support for awstranscriber
  - Bayer 10/12/14/16-bit depth support
  - MPEG-TS support for asynchronous KLV demuxing and segment
    seeking, plus various new muxer features
  - Capture source and sink for AJA capture and playout cards
  - SVT-AV1 and VA-API AV1 encoders, stateless AV1 video decoder
  - New uvcsink element for exporting streams as UVC camera
  - DirectWrite text rendering plugin for windows
  - Direct3D12-based video decoding, conversion, composition, and
    rendering
  - AMD Advanced Media Framework AV1 + H.265 video encoders with
    10-bit and HDR support
  - AVX/AVX2 support and NEON support on macOS on Apple ARM64
    CPUs via new liborc
  - GStreamer C# bindings have been updated
  - Rust bindings improvements and many new and improved Rust
    plugins
  - Rust plugins now shipped in packages for all major platforms
    including Android and iOS
  - Lots of new plugins, features, performance improvements and
    bug fixes
  * For more detailed information on this update, please see
    https://gstreamer.freedesktop.org/releases/1.24/
- Rebase patches:
  * gstreamer-pie.patch
  * gstreamer-rpm-prov.patch
- Remove patch reduce-required-meson.patch since meson 1.1 is
  really required now.
* Thu Feb  1 2024 Antonio Larrosa <alarrosa@suse.com>
- Update to version 1.22.9:
  + Highlighted bugfixes in 1.22.9
  - More Security fixes for the AV1 video codec parser
  - va: fixes for Mesa Gallium drivers in Mesa versions older
    than v23.2
  - v4l2src: Consider framerate during caps selection
  - v4l2codec: decoder fixes
  - rtspsrc: multicast fixes
  - camerabin viewfinder fixes
  - various bug fixes, build fixes, memory leak fixes, and other
    stability and reliability improvements
  + gstreamer
  - aggregator: fix use-after-free in queries processing
  - multiqueue: Ignore queue fullness for most events
- Rebase reduce-required-meson.patch
* Thu Jan  4 2024 Antonio Larrosa <alarrosa@suse.com>
- Update to version 1.22.8:
  + Highlighted bugfixes in 1.22.8
  - Security fixes for the AV1 video codec parser
  - avdec video decoder: fix another possible deadlock with
    FFmpeg 6.1
  - qtdemux: reverse playback and seeking fixes for files with
    raw audio streams
  - v4l2: fix "newly allocated buffer ... is not free" warning
    log flood
  - GstPlay + GstPlayer library fixes
  - dtls: Fix build failure on Windows when compiling against
    OpenSSL 3.2.0
  - d3d11screencapturesrc: Fix wrong color with HDR enabled
  - Cerbero build tool: More python 3.12 string escape warning
    fixes; make sure to bundle build tools as well
  - various bug fixes, build fixes, memory leak fixes, and other
    stability and reliability improvements
  + gstreamer
  - buffer: Unref memories before metas
  - pad: Recheck pads when linking after temporary unlock
  - baseparse: Fixes to buffers extracted from adapter
- Rebase reduce-required-meson.patch
* Wed Nov 15 2023 Antonio Larrosa <alarrosa@suse.com>
- Update to version 1.22.7:
  + Highlighted bugfixes:
  - Security fixes for the MXF demuxer and AV1 codec parser
  - glfilter: Memory leak fix for OpenGL filter elements
  - d3d11videosink: Fix toggling between fullscreen and maximized, and window switching in fullscreen mode
  - DASH / HLS adaptive streaming fixes
  - Decklink card device provider device name string handling fixes
  - interaudiosrc: handle non-interleaved audio properly
  - openh264: Fail gracefully if openh264 encoder/decoder creation fails
  - rtspsrc: improved whitespace handling in response headers by certain cameras
  - v4l2codecs: avoid wrap-around after 1000000 frames; tiled formats handling fixes
  - video-scaler, audio-resampler: downgraded "Can't find exact taps" debug log messages
  - wasapi2: Don't use global volume control object
  - Rust plugins: various improvements in aws, fmp4mux, hlssink3, livesync, ndisrc, rtpav1depay, rsfilesink, s3sink, sccparse
  - WebRTC: various webrtchttp, webrtcsrc, and webrtcsink improvements and fixes
  - Cerbero build tools: recognise Windows 11; restrict parallelism of gst-plugins-rs build on small systems
  - Packages: ca-certificates update; fix gio module loading and TLS support on macOS
  + gstreamer:
  - debugutils: provide gst_debug_bin_to_dot_data() implementation even if debug system is disabled
- Rebase reduce-required-meson.patch
* Fri Sep 22 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.22.6:
  + Highlighted bugfixes:
  - Security fixes for the MXF demuxer and H.265 video parser
  - Fix latency regression in H.264 hardware decoder base class
  - androidmedia: fix HEVC codec profile registration and fix
    coded_data handling
  - decodebin3: fix switching from a raw stream to an encoded
    stream
  - gst-inspect: prettier and more correct signal and action
    signals printing
  - rtmp2: Allow NULL flash version, omitting the field, for
    better RTMP server compatibility
  - rtspsrc: better compatibility with buggy RTSP servers that
    don't set a clock-rate
  - rtpjitterbuffer: fix integer overflow that led to more
    packets being declared lost than have been lost
  - v4l2: fix video encoding regression on RPi and fix support
    for left and top padding
  - waylandsink: Crop surfaces to their display width height
  - cerbero: Recognise Manjaro; add Rust support for MSVC ARM64;
    cmake detection fixes
  - Various bug fixes, memory leak fixes, and other stability and
    reliability improvements
  + gstreamer:
  - gst-inspect: prettier and more correct signal printing, and
    print action signals in g_signal_emit_by_name() format
  - gst-launch: Disable fault signal handlers on macOS
- Rebase reduce-required-meson.patch
* Tue Jul 25 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.22.5:
  + Highlighted bugfixes:
  - Security fixes for the RealMedia demuxer
  - vaapi decoders, postproc: Disable DMAbuf from caps
    negotiation to fix garbled video in some cases
  - decodebin3, playbin3, parsebin fixes, especially for stream
    reconfiguration
  - hlsdemux2: fix early seeking; don't pass referer when
    updating playlists; webvtt fixes
  - gtk: Fix critical caused by pointer movement when stream is
    getting ready
  - qt6: Set sampler filtering method, fixes bad quality with
    qml6glsink and gstqt6d3d11
  - v4l2src: handle resolution change when buffers are copied
  - videoflip: update orientation tag in auto mode
  - video timecode: Add support for framerates lower than 1fps
    and accept 119.88 (120/1.001) fps
  - webrtcsink: fixes for x264enc and NVIDIA encoders
  - cerbero: Pull ninja from system if possible, avoid spurious
    bootstrap of cmake
  - packages: Recipe updates for ffmpeg, libsoup, orc
  - various bug fixes, memory leak fixes, and other stability and
    reliability improvements
  + gstreamer:
  - taglist, plugins: fix compiler warnings with GLib >= 2.76
  - tracerutils: allow casting parameter types
  - inputselector: fix playing variable is never set
- Rebase patch.
* Mon Jun 26 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.22.4:
  + Highlighted bugfixes:
  - Security fixes for flacparse, dvdspu, and subparse.
  - d3d11videosink: Fix error on pause and play.
  - decklink: Correctly handle SDK strings on macOS and free
    strings after usage on Linux.
  - filesink: Fix buffered mode writing of buffer lists and
    buffers with multiple memories.
  - gldownload: handle passthrough without a critical.
  - h265parse: Fix framerate handling regression.
  - oggdemux: vp8 fixes.
  - mp4mux, qtmux, qtdemux: Opus audio mapping fixes.
  - pngdec: Fix wrong colours output from 16bit RGB images.
  - ptp clock: Work around ptpd bug in default configuration.
  - srtpdec: fix critical warnings on shutdown.
  - v4l2src: fix support for bayer format.
  - v4l2videoenc: support force-keyframe event in v4l2 encoder.
  - vtenc: apply DTS offset to ensure DTS <= PTS.
  - gst-python: allow more functions to be called before
    gst_init().
  - various bug fixes, memory leak fixes, and other stability and
    reliability improvements.
  + gstreamer:
  - filesink: Fix buffered mode writing of buffer lists and
    buffers with multiple memories.
  - basesink: Clear EOS flag on STREAM-START event.
  - typefindhelper: downgrade bogus error level debug log
    message.
  - ptp:
    . Correctly parse clock ID from the commandline parameters in
    the helper.
    . Work around bug in ptpd in default configuration.
- Rebase reduce-required-meson.patch.
* Wed May 24 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.22.3:
  + Highlighted bugfixes:
  - avdec: fix occasional video decoder deadlock on seeking with
    FFmpeg 6.0.
  - decodebin3: fix regression handling input streams without
    CAPS or TIME segment such as e.g. udpsrc or `pushfilesrc.
  - bluez: a2dpsink: fix Bluetooth SIG Certification test
    failures.
  - osxvideosink: fix deadlock upon closing output window.
  - qtdemux: fix edit list handling regression and AV1 codec box
    parsing.
  - qtmux: fix extraction of CEA608 closed caption data from
    S334-1A packets.
  - rtspsrc: Fix handling of * control path.
  - splitmux: timestamp handling improvements.
  - v4l2videodec: Rework dynamic resolution change handling
    (needed for IMX6 mainline codec).
  - videoflip: fix regression with automatically rotating video
    based on tags.
  - d3d11: many d3d11videosink and d3d11compositor fixes.
  - webrtc, rtp: numerous data race fixes and stability fixes.
  - various bug fixes, memory leak fixes, and other stability and
    reliability improvements.
  + gstreamer:
  - tracing: Initialize tracing infrastructure even if the debug
    system is not compiled in.
  - parse-launch: fix missing unref of looked-up child element.
  - gstutils: Add category and object to most logging messages.
- Rebase reduce-required-meson.patch.
* Wed Apr 12 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.22.2:
  + Highlighted bugfixes:
  - avdec_h264: fix decoder deadlocks with FFmpeg 6.0
  - rtspsrc:
    . fix regression with URI protocols in OPTIONS requests for
    RTSP over TLD
    . improved control url handling compatibility for broken
    servers
  - decklink: fix 10 bit RGB (r210) format auto detection for
    capture and fix playout if video caps are configured before
    audio caps
  - d3d11videosink: Fix tearing in case of fullscreen mode
  - playbin: fix deadlock when stopping stream with subtitles
    visible (even more)
  - typefinding: fix regression not detecting
    application/dash+xml in some corner cases
  - osxvideosink: fix broken aspect ratio and frame drawing
    region
  - decodebin3, parsebin: Improve elementary stream handling when
    decoders are not present and fix hang when removing a failing
    stream
  - urisourcebin: Propagate sticky events from parsebin, so that
    the `STREAM_START` event with the `GstStream` info is always
    available when pads get exposed
  - v4l2: Add support for YVU420M format; mark JPEG content as
    parsed
  - h264decoder, h265decoder: DPB bumping process and latency
    reporting fixes
  - Opus: Fix reading of extended channel config in MPEG-TS and
    fix missing sample rate when remuxing from RTP to Matroska
  - zxing: add support for building against zxing-c++ 2.0
  - cerbero: Fix packaging of Rust plugins on Android; fix modern
    Gentoo distro detection
  - various bug fixes, memory leak fixes, and other stability and
    reliability improvements
  + Gstreamer:
  - datetime: Return G_MAXFLOAT instead of G_MAXDOUBLE for no
    timezone offset
  - inputselector: Wake up streaming thread before
    PLAYING_TO_PAUSED transition
  - tools: fix potential crash when passing command-line options
    on Windows
- Rebase patches with quilt.
* Thu Mar  9 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.22.1:
  + Highlighted bugfixes:
  - audio channel-mix: allow up to 64 channels (instead of up to
    63 channels)
  - avfvideosrc: Don't wait on main thread for permissions
    request
  - avvidenc: avoid generating inaccurate output timestamps,
    especially with variable framerate streams
  - AV1 video codec caps signalling improvements in various
    elements
  - codectimestamper: Fix timestamping on sequence update
  - d3d11overlaycompositor: fix texture width and height
  - d3d11videosink: Fix rendering on external handle
  - dashdemux2: fix seek operation taking a log time to finish
    for some streams
  - nvencoder: Fix B-frame encoding on Linux and min buffers in
    auto GPU mode
  - playbin3: fixing buffering for live pipelines
  - playbin: fix potential deadlock when stopping stream with
    subtitles visible
  - redenc: fix setting of extension ID for twcc
  - rtspsrc: improved compatibility with more broken RTSP servers
  - v4l2h264dec: Fix Raspberry Pi4 will not play video in
    application
  - vtdec: fix jittery playback of H.264 Level 4.1 movies in
    macOS
  - vtdec: Fix non-deterministic frame output after flushing
    seeks
  - vtenc: fix handling of interlaced ProRes on Apple M1 hardware
  - vtenc: don't advertise ARGB/RGBA64 input caps on M1 Pro/Max
    with macOS <13
  - wasapi2src: Fix loopback capture on Windows 10 Anniversary
    Update
  - tools: better handling of non-ASCII command line arguments on
    Windows
  - gst-libav: fix build against newer ffmpeg versions
  - gst-python: Use arch-specific install dir for gi overrides
  - cerbero: Fix setuptools site.py breakage in Python 3.11
  - macOS packages: Fix broken binaries on macos < 11.0
  - various bug fixes, memory leak fixes, and other stability and
    reliability improvements
  + gstreamer:
  - buffer: fix copy meta reference debug log formatting
  - bin: Don't unlock unlocked mutex in gst_bin_remove_func()
  - pad: Don't leak user_data in gst_pad_start_task()
  - aggregator: Always lock aggpad around update_time_level
  - inputselector: Avoid potential deadlock when shutting down,
    e.g. playbin with subtitles
  - multiqueue: Handle use-interleave latency live pipelines,
    fixing buffering for live pipelines in playbin3
  - GstBaseSrc: fix transfer annotation for fixate() virtual
    method
  - GstBaseSrc, GstPushSrc: add nullable annotations to virtual
    methods
  - tools: Make sure UTF-8 encoded command line arguments on
    Windows
- Rebase patches with quilt.
* Tue Feb  7 2023 munix9@googlemail.com
- Add fix using sed to find gst-plugin-scanner-%%{_target_cpu}
  program (boo#1207908).
* Fri Jan 27 2023 Antonio Larrosa <alarrosa@suse.com>
- Add patch to reduce the required meson version to 0.61.0 since
  that's what we have in SLE 15:
  * reduce-required-meson.patch
- Probably because of a problem in SLE's meson, the generated
  pkgconfig files are missing some variables that are needed by
  rpm to generate the pkgconfig(...) provides correctly. In order
  to fix this, we now check for those variables and insert them
  in the pc files before installation if they're missing.
* Tue Jan 24 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.22.0:
  + AV1 video codec support improvements
  + New HLS, DASH and Microsoft Smooth Streaming adaptive streaming
    clients
  + Qt6 support for rendering video inside a QML scene
  + Minimal builds optimised for binary size, including only the
    individual elements needed
  + Playbin3, Decodebin3, UriDecodebin3, Parsebin enhancements and
    stabilisation
  + WebRTC simulcast support and support for Google Congestion
    Control
  + WebRTC-based media server ingestion/egress (WHIP/WHEP) support
  + New easy to use batteries-included WebRTC sender plugin
  + Easy RTP sender timestamp reconstruction for RTP and RTSP
  + ONVIF timed metadata support
  + New fragmented MP4 muxer and non-fragmented MP4 muxer
  + New plugins for Amazon AWS storage and audio transcription
    services
  + New gtk4paintablesink and gtkwaylandsink renderers
  + New videocolorscale element that can convert and scale in one
    go for better performance
  + High bit-depth video improvements
  + Touchscreen event support in navigation API
  + Rust plugins now shipped in macOS and Windows/MSVC binary
    packages
  + H.264/H.265 timestamp correction elements for PTS/DTS
    reconstruction before muxers
  + Improved design for DMA buffer sharing and modifier handling
    for hardware-accelerated video decoders/encoders/filters and
    capturing/rendering on Linux
  + Video4Linux2 hardware accelerated decoder improvements
  + CUDA integration and Direct3D11 integration and plugin
    improvements
  + New H.264 / AVC, H.265 / HEVC and AV1 hardware-accelerated
    video encoders for AMD GPUs using the Advanced Media Framework
    (AMF) SDK
  + applemedia: H.265 / HEVC video encoding + decoding support
  + androidmedia: H.265 / HEVC video encoding support
  + New "force-live" property for audiomixer, compositor,
    glvideomixer, d3d11compositor etc.
  + Lots of new plugins, features, performance improvements and bug
    fixes
- Rebase patches with quilt.
* Thu Dec 22 2022 Dirk Müller <dmueller@suse.com>
- update to 1.20.5:
  + This release only contains bugfixes and it should be safe to
    upgrade from 1.20.x.
  + systemclock waiting fixes for certain 32-bit platforms/libcs
  + alphacombine: robustness improvements for corner case scenarios
  + avfvideosrc: Report latency when doing screen capture
  + d3d11videosink: various thread-safety and stability fixes
  + decklink: fix performance issue when HDMI signal has been lost
    for a long time
  + flacparse: Fix handling of headers advertising 32 bits per
    sample
  + mpegts: Handle when iconv doesn't support ISO 6937 (e.g. musl
    libc)
  + opengl: fix automatic dispmanx detection for rpi4 and fix usage
    of eglCreate/DestroyImage
  + opusdec: Various channel-related fixes
  + textrender: event handling fixes, esp. for GAP event
  + subparse: Fix non-closed tag handling
  + videoscale: fix handling of unknown buffer metas
  + videosink: reverse playback handling fixes
  + qtmux: Prefill mode fixes, especially for raw audio
  + multiudpsink: allow binding to IPv6 address
  + rtspsrc:
  - Fix usage of IPv6 connections in SETUP
  - Only EOS on timeout if all streams are timed out/EOS
  + splitmuxsrc: fix playback stall if there are unlinked pads
  + v4l2: Fix SIGSEGV on state change during format changes
  + wavparse robustness fixes
  + Fix static linking on macOS (opengl, vulkan)
  + gstreamer-vaapi: fix headless build against mesa >= 22.3.0
  + GStreamer Editing Services library: Fix build with tools
    disabled
  + webrtc example/demo fixes
  + unit test fixes for aesdec and rtpjitterbuffer
  + Cerbero: Fix ios cross-compile with cmake on M1; some recipe
    updates and other build fixes
  + Miscellaneous bug fixes, memory leak fixes, and other stability
    and reliability improvements
  + Performance improvements
  + Changes in gstreamer base package:
  - allocator: Copy allocator name in gst_allocator_register()
  - concat: Properly propagate EOS seqnum
  - fakesrc: avoid time overflow with datarate
  - Fix build of 1.20 branch with Meson 0.64.1 for those who have
    hotdoc installed on their system.
  - gst-inspect: Don't leak list
  - meson: fix check for pthread_setname_np()
  - miniobject: support higher refcount values
  - pads: Fix non-serialized sticky event push, e.g. instant
    change rate events
  - padtemplate: Fix annotations
  - systemclock: Use futex_time64 syscall on x32 and other
    platforms that always...
  - -Wimplicit-function-declaration in pthread_setname_np check
    (missing GNUSOURCE)
* Fri Oct 21 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.20.4:
  + Highlighted bugfixes in 1.20.4:
  - avaudiodec: fix playback issue with WMA files, would throw an
    error at EOS with FFmpeg 5.x
  - Fix deadlock when loading gst-editing-services plugin
  - Fix input buffering capacity in live mode for aggregator,
    video/audio aggregator subclasses, muxers
  - glimagesink: fix crash on Android
  - subtitle handling and subtitle overlay fixes
  - matroska-mux: allow width + height changes for
    avc3|hev1|vp8|vp9
  - rtspsrc: fix control url handling for spec compliant servers
    and add fallback for incompliant servers
  - WebRTC fixes
  - RTP retransmission fixes
  - video: fixes for formats with 4x subsampling and horizontal
    co-sited chroma (Y41B, YUV9, YVU9 and IYU9)
  - Fix consuming of the macOS package as a framework in XCode
  - Performance improvements
  - Miscellaneous bug fixes, memory leak fixes, and other
    stability and reliability improvements
  + gstreamer:
  - buffer: drop parent meta in deep copy/foreach_metadata
  - devicemonitor: Use a sync bus handler for the provider to
    avoid accumulating all messages until the provider is stopped
  - element: Fix requesting of pads with string templates
  - gst:
    . Protect initialization state with a recursive mutex
    . Add missing define guard for build without gstreamer debug
    logging support
  - gst_init: Initialize static plugins just before dynamic plugins
  - info: Parse "NONE" as a valid level name
  - meta: Set the parent refcount of the GstStructure correctly
  - pluginloader: Don't hang on short reads/writes
  - tracers: leaks:
    . Fix potentially invalid memory access when trying to detect
    object type
    . Fix object-refings.class flags
  - uri: When setting the same string again do nothing
  - value: Don't loop forever when serializing invalid flag
  + Base Libraries:
  - aggregator:
    . Fix input buffering in live mode (was too low before in
    many cases)
    . Fix reversed active/flushing arguments in debug log output
    . Reset EOS flag after receiving a stream-start event
  + Core Elements: queue2:
  - Hold the lock when modifying sinkresult
  - Fix deadlock when deactivate is called in pull mode
* Wed Jun 22 2022 Aaron Stern <ukbeast89@protonmail.com>
- Update to version 1.20.3
  + Highlighted bugfixes:
  - Security fixes in Matroska, MP4 and AVI demuxers
  - Fix scrambled video playback with hardware-accelerated
    VA-API decoders on certain Intel hardware
  - playbin3/decodebin3 regression fix for unhandled streams
  - Fragmented MP4 playback fixes
  - Android H.265 encoder mapping
  - Playback of MXF files produced by FFmpeg before March 2022
  - Fix rtmp2sink crashes on 32-bit platforms
  - WebRTC improvements
  - D3D11 video decoder and screen recorder fixes
  - Performance improvements
  - Support for building against OpenCV 4.6 and other build fixes
  - Miscellaneous bug fixes, memory leak fixes, and other
    stability and reliability improvements
  + gstreamer:
  - clock: Avoid creating a weakref with every entry
    (performance improvement)
  - plugin: add Apache 2 license to list of known licenses to avoid
    warning
  - gst_plugin_load_file: force plugin reload if filename differs
    Add support for LoongArch
* Mon May  9 2022 Andreas Schwab <schwab@suse.de>
- Enable use of libunwind on riscv64
* Mon May  9 2022 Markéta Machová <mmachova@suse.com>
- Update to version 1.20.2
  + Highlighted bugfixes:
  - avviddec: Remove vc1/wmv3 override and fix crashes on WMV
    files with FFMPEG 5.0+
  - macOS: fix plugin discovery for GStreamer installed via brew
    and fix loading of Rust plugins
  - rtpbasepayload: various header extension handling fixes
  - rtpopusdepay: fix regression in stereo input handling if
    sprop-stereo is not advertised
  - rtspclientsink: fix possible shutdown deadlock
  - mpegts: gracefully handle "empty" program maps and fix AC-4
    detection
  - mxfdemux: Handle empty VANC packets and fix EOS handling
  - playbin3: various playbin3, uridecodebin3, and playsink fixes
  - ptpclock: fix initial sync-up with certain devices
  - gltransformation: let graphene alloc its structures memory
    aligned
  - webrtcbin fixes and webrtc sendrecv example improvements
  - video4linux2: various fixes including some fixes for
    Raspberry Pi users
  - videorate segment handling fixes and other fixes
  - nvh264dec, nvh265dec: Fix broken key-unit trick modes and
    reverse playback
  - wpe: Reintroduce persistent WebContext
  - cerbero: Make it easier to consume 1.20.1 macOS GStreamer
    .pkgs
  - build fixes and gobject annotation fixes
  - bug fixes, security fixes, memory leak fixes, and other
    stability and reliability improvements
  + gstreamer:
  - devicemonitor: clean up signal handlers and hidden providers
    list
  - Leaks tracer: fix pthread_atfork return value check leading
    to bogus warning in log
  - Rust plugins: Not picked up by the plugin loader on macOS
  - Failed to use plugins of latest GStreamer version 1.20.x
    installed by brew on macOS
  - ptpclock: Allow at least 100ms delay between Sync/Follow_Up
    and Delay_Req/Delay_Resp messages. Fixes problems acquiring
    initial sync with certain devices
  - meson: Add -Wl,-rpath,${libdir} on macOS
  - registry: skip Rust dep builddirs when searching for plugins
    recursively
* Fri Mar 18 2022 Antonio Larrosa <alarrosa@suse.com>
- Update to version 1.20.1:
  + deinterlace: various bug fixes for yadif, greedy and scalerbob
    methods
  + gtk video sink: Fix rotation not being applied when paused
  + gst-play-1.0: Fix trick-mode handling in keyboard shortcut
  + jpegdec: fix RGB conversion handling
  + matroskademux: improved ProRes video handling
  + matroskamux: Handle multiview-mode/flags/pixel-aspect-ratio
    caps fields correctly when checking caps equality on input caps
    changes
  + videoaggregator fixes (negative rate handling, current position
    rounding)
  + soup http plugin: Lookup libsoup dylib files on Apple
    platforms; fix Cerbero static build on Android and iOS
  + Support build against libfreeaptx in openaptx plugin
  + Fix linking issues on Illumos distros
  + GstPlay: Fix new error + warning parsing API (was unusuable
    before)
  + mpegtsmux: VBR muxing fixes
  + nvdecoder: Various fixes for 4:4:4 and high-bitdepth decoding
  + Support build against libfreeaptx in openaptx plugin
  + webrtc: Various fixes to the webrtc-sendrecv python example
  + macOS: support a relocatable `GStreamer.framework` on macOS
  + macOS: fix applemedia plugin failing to load on ARM64 macOS
  + windows: ship wavpack library
  + gst-python: Fix build with Python 3.11
  + various bug fixes, memory leak fixes, and other stability and
    reliability improvements
  + plugin loader: show the reason when spawning of
    gst-plugin-scanner fails
  + registry, plugin loading: fix dynamic relocation if
    GST_PLUGIN_SUBDIR (libdir) is not a single subdirectory;
    improve GST_PLUGIN_SUBDIR handling
  + context: fix transfer annotation on
    gst_context_writable_structure() for bindings
  + baseparse: Don't truncate the duration to milliseconds in
    gst_base_parse_convert_default()
  + bufferpool: Deactivate pool and get rid of references to other
    objects from dispose instead of finalize
* Fri Feb  4 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.20.0:
  + Development in GitLab was switched to a single git repository
    containing all the modules
  + GstPlay: new high-level playback library, replaces GstPlayer
  + WebM Alpha decoding support
  + Encoding profiles can now be tweaked with additional
    application-specified element properties
  + Compositor: multi-threaded video conversion and mixing
  + RTP header extensions: unified support in RTP depayloader and
    payloader base classes
  + SMPTE 2022-1 2-D Forward Error Correction support
  + Smart encoding (pass through) support for VP8, VP9, H.265 in
    encodebin and transcodebin
  + Runtime compatibility support for libsoup2 and libsoup3
    (libsoup3 support experimental)
  + Video decoder subframe support
  + Video decoder automatic packet-loss, data corruption, and
    keyframe request handling for RTP / WebRTC / RTSP
  + mp4 and Matroska muxers now support profile/level/resolution
    changes for H.264/H.265 input streams (i.e. codec data changing
    on the fly)
  + mp4 muxing mode that initially creates a fragmented mp4 which
    is converted to a regular mp4 on EOS
  + Audio support for the WebKit Port for Embedded (WPE) web page
    source element
  + CUDA based video color space convert and rescale elements and
    upload/download elements
  + NVIDIA memory:NVMM support for OpenGL glupload and gldownload
    elements
  + Many WebRTC improvements
  + The new VA-API plugin implementation fleshed out with more
    decoders and new postproc elements
  + AppSink API to retrieve events in addition to buffers and
    buffer lists
  + AppSrc gained more configuration options for the internal queue
    (leakiness, limits in buffers and time, getters to read current
    levels)
  + Updated Rust bindings and many new Rust plugins
  + Improved support for custom minimal GStreamer builds
  + Support build against FFmpeg 5.0
  + Linux Stateless CODEC support gained MPEG-2 and VP9
  + Windows Direct3D11/DXVA decoder gained AV1 and MPEG-2 support
  + Lots of new plugins, features, performance improvements and bug
    fixes
- Use ldconfig_scriptlets macro for post(un) handling where
  possible.
- Update Source url.
* Fri Feb  4 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.18.6:
  + gstplugin: Fix for UWP build
  + gst-ptp-helper: Do not disable multicast loopback
  + concat: fix qos event handling
  + pluginfeature: Fix object leak
  + baseparse: fix invalid avg_bitrate after reset
  + multiqueue: Fix query unref race on flush
  + gst: Initialize optional event/message fields when parsing
  + bitwriter: Fix the trailing bits lost when getting its data
  + multiqueue: never consider a queue that is not waiting
  + input-selector: Use proper segments when cleaning cached
    buffers
* Thu Sep 16 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Stop building doc sub-package, we will in the future use
  upstreams own standalone doc package. Following this: Drop
  fdupes, gtk-doc and hotdoc BuildRequires, and fdupes call, no
  longer needed nor usefull.
- Refresh patches with quilt.
* Thu Sep 16 2021 Stanislav Brabec <sbrabec@suse.com>
- Remove obsolete translation-update-upstream and
  gnome-patch-translation support (jsc#SLE-21105).
* Wed Sep 15 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.18.5:
  + aggregator:
  - Release the SRC lock while querying latency
  - Release pads' peeked buffer when removing the pad or
    finalizing it
  + basesink: Don't swap rstart/rstop when stepping
  + basesrc: Print segments with GST_SEGMENT_FORMAT and not
    GST_PTR_FORMAT
  + childproxy: init value in gst_child_proxy_get_property() if
    needed
  + clocksync: Fix providing system clock by default
  + concat:
  - Properly propagate seqnum of segment events
  - adjust running time offsets on downstream events
  - fix locking in SEGMENT event handler
  + downloadbuffer/sparsefile: several fixes for win32
  + element: NULL the lists of contexts in dispose()
  + multiqueue:
  - Use running time of gap events for wakeups.
  - Ensure peer pad exists when iterating internal links
  + pad:
  - Keep IDLE probe hook alive during immediate callback
  - Ensure last flow return is set on sink pads in push mode
  - Don't spam the debug log at INFO level when default-chaining
    a buffer list
  - clear probes holding mutex
  + parse-launch:
  - Fix a critical when using the : operator.
  + Don't do delayed property setting for top-level properties.
  + plugin: load plugins with unknown license strings
  + ptpclock: Don't leak the GList
  + queue2: Refuse all serialized queries when posting buffering
    messages
  + systemclock: Update monotonic reference time when re-scheduling
  + High CPU usage in 1.18 (but not master) when pausing playback
    in gnome-music
  + Don't use volatile to mean atomic (fixes compiler warnings with
    gcc 11)
* Fri Mar 19 2021 Dirk Müller <dmueller@suse.com>
- update to 1.18.4:
  important security fixes for ID3 tag reading, matroska and realmedia
  parsing, and gst-libav audio decoding
  Details:
  * audiomixer, audioaggregator: input buffer handling fixes
  * decodebin3: improve stream-selection message handling
  * uridecodebin3: make “caps” property work
  * wavenc: fix writing of INFO chunks in some cases
  * v4l2: bt601 colorimetry, allow encoder resolution changes, fix
    decoder frame rate negotiation
  * decklinkvideosink: fix auto format detection, and fixes for 29.97fps
    framerate output
  * mpeg-2 video handling fixes when seeking
  * avviddec: fix bufferpool negotiation and possible memory corruption
    when changing resolution
  * various stability, performance and reliability improvements
  * memory leak fixes
  * build fixes: rpicamsrc, qt overlay example, d3d11videosink on UWP
  * info: Don’t leak log function user_data if the debug system is
    compiled out
  * task: Use SetThreadDescription() Win32 API for setting thread names,
    which preserves thread names in dump files.
  * buffer, memory: Mark info in map functions as caller-allocates and
    pass allocation params as const pointers where possible
  * clock: define AUTO_CLEANUP_FREE_FUNC for GstClockID
  * tag: id3v2: fix frame size check and potential invalid reads
  * audio: Fix gst_audio_buffer_truncate() meta handling for
    non-interleaved audio
  * audioresample: respect buffer layout when draining
  * audioaggregator: fix input_buffer ownership
  * decodebin3: change stream selection message owner, so that the app
    sends the stream-selection event to the right element
  * rtspconnection: correct data_size when tunneled mode
  * uridecodebin3: make caps property work
  * video-converter: Don’t upsample invalid lines
  * videodecoder: Fix racy critical when pool negotiation occurs during
    flush
  * video: Convert gst_video_info_to_caps() to take self as const ptr
  * examples: added qt core dependency for qt overlay example
  * matroskademux: header parsing fixes
  * rpicamsrc: depend on posix threads and vchiq_arm to fix build on
    raspios again
  * wavenc: Fixed INFO chunk corruption, caused by odd sized data not
    being padded
  * wavpackdec: Add floating point format support to fix distortions in
    some cases
  * v4l2: recognize V4L2 bt601 colorimetry again
  * v4l2videoenc: support resolution change stream encode
  * v4l2h265codec: fix HEVC profile string issue
  * v4l2object: Need keep same transfer as input caps
  * v4l2videodec: Fix vp8 and vp9 streams can’t play on board with
    vendor bsp
  * v4l2videodec: fix src side frame rate negotiation
  * avwait: Don’t post messages with the mutex locked
  * d3d11h264dec: Reconfigure decoder object on DPB size change and keep
    track of actually configured DPB size
  * dashsink: fix double unref of sinkpad caps
  * decklinkvideosink: Use correct numerator for 29.97fps
  * decklinkvideosink: fix auto format detection
  * decklinksrc: Use a more accurate capture time
  * d3d11videosink: Fix build error on UWP
  * interlace: negotiation and buffer leak fixes
  * mpegvideoparse: do not clip, so decoder receives data from keyframe
    even if it’s before the segment start
  * mpegtsparse: Fix switched DTS/PTS when set-timestamps=false
  * nvh264sldec: Reopen decoder object if larger DPB size is required
  * sdpsrc: fix double free if sdp is provided as string via the
    property
  * vulkan: Fix elements long name.
* Sat Jan 16 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.18.3:
  + Highlighted bugfixes:
  - Fix ogg playback regression for ogg files that also have ID3
    or APE tags
  - compositor: fix artefacts and invalid memory access when
    blending subsampled formats
  - Exported mini object ref/unref/copy functions for use in
    bindings such as gstreamer-sharp
  - Add support for Apple silicon (M1) to cerbero package builder
  - Ship RIST plugin in binary packages
  - Various stability, performance and reliability improvements
  - Memory leak fixes
  - Build fixes
  + gstreamer:
  - gst: Add non-inline ref/unref/copy/replace methods for
    various mini objects (buffer, bufferlist, caps, context,
    event, memory, message, promise, query, sample, taglist, uri)
    for use in bindings such as gstreamer-sharp.
  - harness: don't use GST_DEBUG_OBJECT with GstHarness which is
    not a GObject.
* Wed Dec 30 2020 Frederic Crozat <fcrozat@suse.com>
- Move gst-plugins-doc-cache-generator to devel subpackage
  (remove python3 dependency on main gstreamer package).
* Tue Dec  8 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.18.2:
  + Highlighted bugfixes:
  - Fix MPEG-TS timestamping regression when playing DVB streams
  - compositor: fix artefacts in certain input scaling/conversion
    situations and make sure that the output format is actually
    supported, plus renegotiation fixes
  - Fix sftp:// URI playback in decodebin/playbin via giosrc
  - adaptivedemux/dashdemux/hlsdemux fixes
  - rtsp-server fixes
  - android media: fix crash when encoding AVC
  - fix races in various unit tests
  - lots of other bug fixes and memory leak fixes
  - various stability, performance and reliability improvements
  - g-i annotation fixes
  - build fixes
  + gstreamer changes:
  - bin: When removing a sink, check if the EOS status changed
  - info: colorize PIDs in log messages
  - aggregator: Include min-upstream-latency in buffering time,
    helps especially with performance issues on single core
    systems where there are a lot of threads running
  - typefind: copy seqnum to new segment event, fixing issues
    with oggdemux operating in push mode with typefind operating
    in pull mode
  - identity, clocksync: Also provide system clock if sync=false
  - queue2: Fix modes in scheduling query handling
  - harness: Handle element not being set cleanly
  - g-i: Add some missing nullable annotations, and fix some
    nullable annotations:
  - gst_test_clock_process_next_clock_id() returns nullable
  - gst_stream_type_get_name() is not nullable
  - build: fix build issue when compiling for 32-bit
    architectures with 64-bit time_t (e.g. riscv32) by increasing
    padding in GstClockEntryImpl in gst_private.h
- Fix the _service file and spec to really use the tarball
  generated by service.
* Tue Oct 27 2020 Antonio Larrosa <alarrosa@suse.com>
- Update to 1.18.1:
  + Highlighted bugfixes in 1.18.1
  - important security fixes (bsc#1181255, CVE-2021-3185)
  - bug fixes and memory leak fixes
  - various stability and reliability improvements
  + gstreamer changes:
  - aggregator: make peek() has() pop() drop() buffer API
    threadsafe
  - gstvalue: don't write to const char *
  - meson: Disallow DbgHelp for UWP build
  - info: Fix build on Windows ARM64 device
  - build: use cpu_family for arch checks
  - basetransform: Fix in/outbuf confusion of
    _default_transform_meta
  - Fix documentation
  - info: Load DbgHelp.dll using g_module_open()
  - padtemplate: mark documentation caps as may be leaked
  - gstmeta: intern registered impl string
  - aggregator: Hold SRC_LOCK while unblocking via
    SRC_BROADCAST()
  - ptp_helper_post_install.sh: deal with none
  - skip elements/leak.c if tracer is not available
  - aggregator: Wake up source pad in PAUSED<->PLAYING
    transitions
  - input-selector: Wake up blocking pads when releasing them
  - ptp: Also handle gnu/kfreebsd
* Sat Oct 24 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Do not manually install gst-tester-%%{gst_branch}: meson_install
  takes care of this already.
* Thu Sep 10 2020 Antonio Larrosa <alarrosa@suse.com>
- Update to 1.18.0:
  + Highlights:
  - GstTranscoder: new high level API for applications to
    transcode media files from one format to another
  - High Dynamic Range (HDR) video information representation
    and signalling enhancements
  - Instant playback rate change support
  - Active Format Description (AFD) and Bar Data support
  - RTSP server and client implementations gained ONVIF trick
    modes support
  - Hardware-accelerated video decoding on Windows via
    DXVA2/Direct3D11
  - Microsoft Media Foundation plugin for video capture and
    hardware-accelerated video encoding on Windows
  - qmlgloverlay: New overlay element that renders a QtQuick
    scene over the top of an input video stream
  - imagesequencesrc: New element to easily create a video
    stream from a sequence of jpeg or png images
  - dashsink: New sink to produce DASH content
  - dvbsubenc: New DVB Subtitle encoder element
  - MPEG-TS muxing now also supports TV broadcast compliant
    muxing with constant bitrate muxing and SCTE-35 support
  - rtmp2: New RTMP client source and sink element from-scratch
    implementation
  - svthevcenc: New SVT-HEVC-based H.265 video encoder
  - vaapioverlay: New compositor element using VA-API
  - rtpmanager gained support for Google's Transport-Wide
    Congestion Control (twcc) RTP extension
  - splitmuxsink and splitmuxsrc gained support for auxiliary
    video streams
  - webrtcbin now contains some initial support for
    renegotiation involving stream addition and removal
  - RTP support was enhanced with new RTP source and sink
    elements to easily set up RTP streaming via rtp:// URIs
  - avtp: New Audio Video Transport Protocol (AVTP) plugin for
    Time-Sensitive Applications
  - Support for the Video Services Forum's Reliable Internet
    Stream Transport (RIST) TR-06-1 Simple Profile
  - Universal Windows Platform (UWP) support
  - rpicamsrc: New element for capturing from the Raspberry Pi
    camera
  - RTSP Server TCP interleaved backpressure handling
    improvements as well as support for Scale/Speed headers
  - GStreamer Editing Services gained support for nested
    timelines, per-clip speed rate control and the OpenTimelineIO
    format.
  - Autotools build system has been removed in favour of Meson
- Remove patches from upstream:
  * gstreamer-revert-encforce-elements.patch
- Rebase gstreamer-rpm-prov.patch.
- Don't disable tests when configuring the build so gst-tester-1.0
  is built and installed, since it's required by
  gstreamer-plugins-base.
* Sat May 30 2020 Marcus Meissner <meissner@suse.com>
- adjust / ship more 32bit stuff for Wine usage (bsc#1172304)
* Thu Apr 30 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Fix file-list, needed due to libexecdir move, and our previously
  wrong usage of libexecdir.
* Fri Jan 31 2020 Bjørn Lie <bjorn.lie@gmail.com>
- No longer recommend -lang: supplements are in use.
* Mon Dec 23 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Add gstreamer-revert-encforce-elements.patch: Revert enforce
  elements, patches from upstream stable branch.
* Wed Dec  4 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.16.2:
  + Interlaced video scaling fixes
  + CineForm video support in AVI
  + audioresample: avoid glitches due to rounding errors after
    changing rate
  + Command line tool output printing improvements on Windows
  + various performance improvements, memory leak fixes and
    security fixes
  + VP9 decoding fixes
  + wasapi: bug fixes and stability improvements
  + tsdemux: improved handling of certain discontinuities
  + vaapi h265 decoder: wait for I-frame before trying to decode
  + tee: Make sure to actually deactivate pads that are released
  + bin: Drop need-context messages without source instead of
    crashing
  + gst: Don't pass miniobjects to GST_DEBUG_OBJECT() and similar
    macros
  + tracers: Don't leak temporary GstStructure
* Tue Sep 24 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.16.1:
  + GStreamer-vaapi: fix green frames and decoding artefacts in
    some cases.
  + OpenGL: fix wayland event source burning CPU in certain
    circumstances.
  + Memory leak fixes and memory footprint improvements.
  + Performance improvements.
  + Stability and security fixes.
  + Fix enum for GST_MESSAGE_DEVICE_CHANGED which is technically an
    API break, but this is only used internally in GStreamer and
    duplicated another message enum.
  + hls: Make crypto dependency optional when hls-crypto is auto.
  + player: fix switching back and forth between forward and
    reverse playback.
  + decklinkaudiosink: Drop late buffers.
  + openh264enc: Fix compilation with openh264 v2.0.
  + wasapisrc: fix segtotal value being always 2.
* Wed Jul 10 2019 Dominique Leuenberger <dimstar@opensuse.org>
- Fix meson script using sed: since we rename gst-plugin-helper for
  multi arch purpose, we also need to fix meson.build to make the
  code look for the correct name (boo#1140998).
* Mon Jul  1 2019 Andreas Schwab <schwab@suse.de>
- Use libunwind only if available
* Wed Jun 12 2019 mgorse@suse.com
- Update to version 1.16.0:
  + Highlights
  - GStreamer WebRTC stack gained support for data channels for
    peer-to-peer communication based on SCTP, BUNDLE support,
    as well as support for multiple TURN servers.
  - AV1 video codec support for Matroska and QuickTime/MP4
    containers and more configuration options and supported
    input formats for the AOMedia AV1 encoder
  - Support for Closed Captions and other Ancillary Data in video
  - Support for planar (non-interleaved) raw audio
  - GstVideoAggregator, compositor and OpenGL mixer elements are
    now in -base
  - New alternate fields interlace mode where each buffer carries
    a single field
  - WebM and Matroska ContentEncryption support in the Matroska
    demuxer
  - new WebKit WPE-based web browser source element
  - Video4Linux: HEVC encoding and decoding, JPEG encoding, and
    improved dmabuf import/export
  - Hardware-accelerated Nvidia video decoder gained support for
    VP8/VP9 decoding, whilst the encoder gained support for
    H.265/HEVC encoding.
  - Many improvements to the Intel Media SDK based
    hardware-accelerated video decoder and encoder plugin
    (msdk): dmabuf import/export for zero-copy integration with
    other components; VP9 decoding; 10-bit HEVC encoding; video
    post-processing (vpp) support including deinterlacing; and
    the video decoder now handles dynamic resolution changes.
  - The ASS/SSA subtitle overlay renderer can now handle multiple
    subtitles that overlap in time and will show them on screen
    simultaneously
  - The Meson build is now feature-complete (*) and it is now the
    recommended build system on all platforms. The Autotools
    build is scheduled to be removed in the next cycle.
  - The GStreamer Rust bindings and Rust plugins module are now
    officially part of upstream GStreamer.
  - The GStreamer Editing Services gained a gesdemux element
    that allows directly playing back serialized edit list with
    playbin or (uri)decodebin
  - Many performance improvements
- Switch to meson on Tumbleweed.
- Rebase gstreamer-rpm-prov.patch.
- Require libdw. Helps with generating backtraces.
- Place gdb autoload files in -devel package.
- Add gstreamer-pie.patch to generate position-independent
  executables. Previously done through CFLAGS/LDFLAGS, but this
  makes ninja pass -pie when linking libraries as well, causing
  the link to fail.
- Now requires glib2 >= 2.40.0.
* Fri May 31 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.14.5:
  + aggregator:
  - Take the pad lock around queue gap event removal.
  - Don’t leak gap buffer when out of segment.
  + buffer: fix possible memory corruption in
    gst_buffer_foreach_meta() when removing metas.
  + bus:
  - Make removing of signal/bus watches thread-safe.
  - Don’t allow removing signal watches with
    gst_bus_remove_watch().
  + controlbinding: Check if the weak pointer was cleared before
    explicitly removing it.
  + ptp clock: Wait for ANNOUNCE before selecting a master;
    increase tolerance for late follow-up and delay-resp.
  + segment: Allow stop == -1 in gst_segment_to_running_time() and
    negative rate.
  + g-i: annotations fixes.
* Wed Oct  3 2018 sean@suspend.net
- Update to version 1.14.4:
  + glviewconvert: wait and set the gl sync meta on buffers.
  + glviewconvert: copy composition meta from the primary buffer to
    both outputs.
  + glcolorconvert: don't copy overlay composition meta over to
    NULL outbufs.
  + matroskademux: add functionality needed for MSE use case fixing
    youtube playback in epiphany/webkit-gtk.
  + tagdemux: Use upstream GST_EVENT_STREAM_START (and stream-id)
    if present.
  + vorbisdec: fix header handling regression: init decoder
    immediately once we have headers.
  + wasapisink: recover from low buffer levels in shared mode.
  + fix GstSegment unit test which would fail on some 32-bit x86
    CPUs.
* Wed Sep 26 2018 bjorn.lie@gmail.com
- Update to version 1.14.3:
  + opusenc: fix crash on 32-bit platforms.
  + compositor: fix major buffer leak when doing crossfading on
    some but not all pads.
  + wasapi: various fixes for wasapisrc and wasapisink regressions.
  + x264enc: Set bit depth to fix "This build of x264 requires
    8-bit depth. Rebuild to..." runtime errors with x264 version
    ≥ 153.
  + audioaggregator, audiomixer: caps negotiation fixes.
  + input-selector: latency handling fixes.
  + playbin, playsink: audio visualization support fixes.
  + dashdemux: fix possible crash if stream is neither isobmff nor
    isoff_ondemand profile.
  + opencv: Fix build for opencv >= 3.4.2.
  + h265parse: miscellaneous fixes backported from h264parse.
  + pads: fix changing of pad offsets from inside pad probes.
  + pads: ensure that pads are blocked for IDLE probes if they are
    called from the streaming thread too.
* Fri Jul 20 2018 bjorn.lie@gmail.com
- Update to version 1.14.2:
  + Update docs.
  + basetransform: Do not check if NULL is an emtpy caps.
  + concat: Properly forward the SEGMENT seqnum.
  + gst: add some GIR array annotations.
  + meson: Fix detection of glib-mkenums under MSYS2.
* Thu Jul 12 2018 dimstar@opensuse.org
- Update gstreamer.macros and gstreamer.prov to be compatible with
  file 5.33, which differently idenfies executables from libraries.
* Sun May 20 2018 bjorn.lie@gmail.com
- Update to version 1.14.1:
  + GstPad: Fix race condition causing the same probe to be called
    multiple times
  + Fix occasional deadlocks on windows when outputting debug
    logging
  + Fix debug levels being applied in the wrong order
  + GIR annotation fixes for bindings
  + audiomixer, audioaggregator: fix some negotiation issues
  + gst-play-1.0: fix leaving stdin in non-blocking mode after exit
  + flvmux: wait for caps on all input pads before writing header
    even if source is live
  + flvmux: don't wake up the muxer unless there is data, fixes
    busy looping if there's no input data
  + flvmux: fix major leak of input buffers
  + rtspsrc, rtsp-server: revert to RTSP RFC handling of
    sendonly/recvonly attributes
  + rtpvrawpay: fix payloading with very large mtu sizes where
    everything fits into a single RTP packet
  + v4l2: Fix hard-coded enabled v4l2 probe on Linux/ARM
  + v4l2: Disable DMABuf for emulated formats when using libv4l2
  + v4l2: Always set colorimetry in S_FMT
  + asfdemux: Set stream-format field for H264 streams and handle
    H.264 in bytestream format
  + x265enc: Fix tagging of keyframes on output buffers
  + ladspa: Fix critical during plugin load on Windows
  + decklink: Fix COM initialisation on Windows
  + h264parse: fix re-use across pipeline stop/restart
  + mpegtsmux: fix force-keyframe event handling and PCR/PMT
    changes that would confuse some players with generated HLS
    streams
  + adaptivedemux: Support period change in live playlist
  + rfbsrc: Fix support for applevncserver and support NULL pool in
    decide_allocation
  + jpegparse: Fix APP1 marker segment parsing
  + h265parse: Make caps writable before modifying them, fixes
    criticals
  + fakevideosink: request an extra buffer if enable-last-sample is
    enabled
  + wasapisrc: Don't provide a clock based on WASAPI's clock
  + wasapi: Only use audioclient3 when low-latency, as it might
    otherwise glitch with slow CPUs or VMs
  + wasapi: Don't derive device period from latency time, should
    make it more robust against glitches
  + audiolatency: Fix wave detection in buffers and avoid bogus pts
    values while starting
  + msdk: fix plugin load on implementations with only HW support
  + msdk: dec: set framerate to the driver only if provided, not in
    0/1 case
  + msdk: Don't set extended coding options for JPEG encode
  + rtponviftimestamp: fix state change function init/reset causing
    races/crashes on shutdown
  + decklink: fix initialization failure in windows binary
  + ladspa: Fix critical warnings during plugin load on Windows and
    fix dependencies in meson build
  + gl: fix cross-compilation error with viv-fb
  + qmlglsink: make work with eglfs_kms
  + rtspclientsink: Don't deadlock in preroll on early close
  + rtspclientsink: Fix client ports for the RTCP backchannel
  + rtsp-server: Fix session timeout when streaming data to client
    over TCP
  + vaapiencode: h264: find best profile in those available, fixing
    negotiation errors
  + vaapi: remove custom GstGL context handling, use GstGL instead.
    Fixes GL Context sharing with WebkitGtk on wayland
  + gst-editing-services: various fixes
  + gst-python: bump pygobject req to 3.8;
    fix GstPad.set_query_function(); dist autogen.sh and
    configure.ac in tarball
  + g-i: pick up GstVideo-1.0.gir from local build directory in
    GstGL build
  + g-i: update constant values for bindings
  + avoid duplicate symbols in plugins across modules in static
    builds
  + ... and many, many more!
* Mon Apr 23 2018 dimstar@opensuse.org
- Rename gst-plugin-scanner to gst-plugin-scanner-%%{arch}, allowing
  multiple variants to co-exist (boo#1049452).
* Fri Mar 30 2018 luc14n0@linuxmail.org
- Update to version 1.14.0:
  + Highlights:
  - WebRTC support: real-time audio/video streaming to and from
    web browsers;
  - Experimental support for the next-gen royalty-free AV1 video
    codec;
  - Video4Linux: encoding support, stable element names and
    faster device probing;
  - Support for the Secure Reliable Transport (SRT) video
    streaming protocol;
  - RTP Forward Error Correction (FEC) support (ULPFEC);
  - RTSP 2.0 support in rtspsrc and gst-rtsp-server;
  - ONVIF audio backchannel support in gst-rtsp-server and
    rtspsrc;
  - playbin3 gapless playback and pre-buffering support;
  - Tee, our stream splitter/duplication element, now does
    allocation query aggregation which is important for efficient
    data handling and zero-copy;
  - QuickTime muxer has a new prefill recording mode that allows
    file import in Adobe Premiere and FinalCut Pro while the file
    is still being written;
  - rtpjitterbuffer fast-start mode and timestamp offset
    adjustment smoothing;
  - souphttpsrc connection sharing, which allows for connection
    reuse, cookie sharing, etc;
  - nvdec: new plugin for hardware-accelerated video decoding
    using the NVIDIA NVDEC API;
  - Adaptive DASH trick play support;
  - ipcpipeline: new plugin that allows splitting a pipeline
    across multiple processes;
  - Major gobject-introspection annotation improvements for large
    parts of the library API;
  - GStreamer C# bindings have been revived and seen many updates
    and fixes;
  - The externally maintained GStreamer Rust bindings had many
    usability improvements and cover most of the API now.
    Coinciding with the 1.14 release, a new release with the 1.14
    API additions is happening.
  + Updated translations.
- Add:
  + gio-2.0, gio-unix-2.0, gmodule-2.0 and gobject-2.0 pkgconfig
    modules BuildRequires to avoid implicit dependencies.
  + libcap-progs BuildRequires: new dependency.
- Drop libxml2-devel BuildRequires: it has been dropped upstream,
  and now so do we.
- Point fdupes to the data directory instead of the build root,
  which is a practice that must be avoided.
- Rebase gstreamer-rpm-prov.patch.
* Thu Mar 29 2018 bjorn.lie@gmail.com
- Update to version 1.12.5:
  + pad: fix some stream deactivation deadlocks/races.
  + registrychunks: don't read from unaligned memory when loading
    registry.
  + ptp: fix build failure with #undef USE_MEASUREMENT_FILTERING.
  + downloadbuffer: Don't hold the mutex while posting the
    download-complete message.
  + playbin3: Fix accessing invalid index in GstStream when
    received select-stream event.
  + id3v2: re-fix handling of ID3 v2.4 tags with extended headers.
  + audio: fix handling of U32BE format.
  + videodecoder: Reset QoS time after pushing segment. This fixes
    playbin gapless playback with videos.
  + subparse: push out of last chunk of text if last line has no
    newline.
  + aacparse: When parsing raw input, accept frames of any size.
    This fixes handling of encoded silence.
  + splitmuxsrc: Improve not-linked handling.
  + rtspsrc: also proxy multicast-iface property to RTCP udpsrc.
  + flacdec: flush flac decoder on lost sync, so that it can
    re-sync.
  + matroskamux: Only mark new clusters as keyframe if they start
    on a keyframe or we're muxing only audio.
  + matroskamux: Clip maximum cluster duration to the maximum
    possible value.
  + h264parse: reset internal 'state' variable properly.
  + x264enc: fix build with newer x264 with support for multiple
    bit depths.
  + x265enc: Fix tagging of keyframes on output buffers.
  + glimagesink: Correct PAR in output caps when transforming.
  + vtdec: destroy and create the GL context on start()/stop(),
    fixing a refcount loop.
  + player: fix criticals when reading info/track properties that
    are NULL.
  + lv2: fix inverted boolean properties.
  + rtponviftimestamp: fix state change function init/reset, fixing
    memory corruption or leaks on shutdown.
  + libav: some build issues fixes.
  + rtsp-server: Place netaddress meta on packets received via TCP.
    Fixes keep-alive via RTCP in TCP interleaved mode.
  + rtsp-server: gi annotation fixes.
  + gst-libav: internal ffmpeg copy was updated to ffmpeg 3.3.6.
  + Various fixes for memory leaks, deadlocks and crashes in all
    modules.
* Tue Mar 20 2018 dimstar@opensuse.org
- Unconditionally enable translation-update-upstream: on
  Tumbleweed, this results in a NOP and for Leap in SLE paid
  translations being used (boo#1086036).
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Mon Dec 11 2017 zaitor@opensuse.org
- Update to version 1.12.4:
  + Dozens of fixes for various issues detected with the help of
    Google's OSS-Fuzz project.
  + Performance regressions with registering debug categories after
    gst_init() were fixed.
  + Regression with seeking back to 0 in souphttpsrc was fixed.
  + Regression with header rewriting in flacparse was fixed.
  + Regression with playbin/playsink leaking sinks was fixed.
  + Inconsistencies with DROPPED/HANDLED handling in pad probe
    handlers are fixed.
  + gst_bin_iterate_sorted() always returns sources last now, as
    documented.
  + gst_query_writable_structure() will never return NULL, for
    consistency with events.
  + Removal of metas from gst_buffer_meta_foreach() works correctly
    now.
  + OpenJPEG plugin builds with OpenJPEG >= 2.3.
  + CDIO plugin builds with CDIO >= 1.0.
  + gstreamer-vaapi works correctly with libva 1.0.
  + gst-libav was updated to ffmpeg 3.3.5.
  + Various fixes for memory leaks, deadlocks and crashes in all
    modules and many, many more!
  + Bugs fixed: bgo#788520, bgo#788617.
  + Updated translations.
* Fri Dec  1 2017 zaitor@opensuse.org
- Add explicit python3-xml BuildRequires: fix build on older
  versions of openSUSE.
* Wed Nov 29 2017 dimstar@opensuse.org
- Switch to python3:
  + Replace python BuildRequires with python3-base.
  + Export PYTHON=/usr/bin/python3 before calling configure.
* Mon Sep 18 2017 zaitor@opensuse.org
- Update to version 1.12.3:
  + Fix for infinite recursion on buffer free in v4l2.
  + Fix for glimagesink crash on macOS when used via autovideosink.
  + Fix for huge overhead in matroskamux caused by writing one
    Cluster per audio-frame in audio-only streams. Also use
    SimpleBlocks for Opus and other audio codecs, which works
    around a bug in VLC that prevented Opus streams to be played
    and decreases overhead even more.
  + Fix for flushing seeks in rtpmsrc always causing an error.
  + Fix for timestamp overflows in calculations in audio encoder
    base class.
  + Fix for RTP h265 depayloader marking P-frames as I-frames.
  + Fix for long connection delays of clients in RTSP server.
  + Fixes for event handling in queue and queue2 elements, and
    updates to buffering levels on NOT_LINKED streams.
  + Various fixes to event and buffering handling in
    decodebin3/playbin3.
  + Various fixes for memory leaks, deadlocks and crashes in all
    modules.
  + Bugs fixed: bgo#778193, bgo#786034, bgo#786056, bgo#786561.
* Fri Aug 25 2017 zaitor@opensuse.org
- Drop conditional valgrind-devel BuildRequires, this type of
  debugging is probably not done by users of binary packages.
* Fri Jul 14 2017 zaitor@opensuse.org
- Update to version 1.12.2:
  + Various fixes for crashes, assertions, deadlocks and memory
    leaks.
  + Regression fix for playback of live HLS streams.
  + Regression fix for crash when playing back a tunneled RTSP
    stream.
  + Regression fix for playback of RLE animations in MOV
    containers.
  + Regression fix for RTP GSM payloading producing corrupted
    output.
  + Major bugfixes to the MXF demuxer, mostly related to seeking
    and fixes to the frame reordering handling in the MXF muxer and
    demuxer.
  + Fix for playback of mono streams on MacOS.
  + More fixes for index handling of ASF containers.
  + Various fixes to adaptivedemux, DASH and HLS demuxers.
  + Fix deadlock in gstreamer-editing-services during class
    initialization.
  + Bugs fixed: bgo#784041, bgo#784932.
* Tue Jun 20 2017 dimstar@opensuse.org
- Update to version 1.12.1:
  + Various fixes for crashes, assertions, deadlocks and memory
    leaks.
  + Fix for regression when seeking to the end of ASF files.
  + Fix for regression in (raw)videoparse that caused it to omit
    video metadata.
  + Fix for regression in discoverer that made it show more streams
    than actually available.
  + Numerous bugfixes to the adaptive demuxer base class and the
    DASH demuxer.
  + Various playbin3/urisourcebin related bugfixes.
  + Vivante DirectVIV (imx6) texture uploader works with
    single-plane (e.g. RGB) video formats now.
  + Intel Media SDK encoder now outputs valid PTS and keyframe
    flags.
  + OpenJPEG2000 plugin can be loaded again on MacOS and correctly
    displays 8 bit RGB images now.
  + Fixes to DirectSound source/sink for high CPU usage and wrong
    latency/buffer size calculations.
  + gst-libav was updated to ffmpeg n3.3.2.
* Fri May  5 2017 zaitor@opensuse.org
- Update to version 1.12.0:
  + Bugs fixed: bgo#782050.
* Wed May  3 2017 dimstar@opensuse.org
- Update to version 1.11.91:
  + Bugs fixed: bgo#781585, bgo#781585, bgo#780757, bgo#781484,
    bgo#781155, bgo#781155, bgo#780903.
- Changes from version 1.11.90:
  + Bugs fixed: bgo#753754, bgo#775445, bgo#776140, bgo#776293,
    bgo#776999, bgo#778193, bgo#778830, bgo#779175, bgo#779459,
    bgo#779755, bgo#779831, bgo#780111, bgo#780751, bgo#780923.
  + Updated translations.
* Fri Feb 24 2017 zaitor@opensuse.org
- Update to version 1.11.2:
  + Bugs fixed: bgo#764707, bgo#773091, bgo#777375, bgo#777449,
    bgo#777780, bgo#777810, bgo#778866.
* Thu Feb 23 2017 zaitor@opensuse.org
- Update to version 1.11.1:
  + padtemplate: Fix null pointer dereference on invalid static
    caps.
  + queue: Don't generate GST_FLOW_ERROR without logging.
  + pad: clarify docs for GST_PAD_PROBE_DROP.
  + meson:
  - Generate pkg-config -uninstalled pc files.
  - Do not generate .pc files for libgstcheck on windows.
  + tools: update gst-inspect man page.
  + Updated translations.
- Stop packaging .la/.a files.
- Rebase gstreamer-rpm-prov.patch.
- Replace glib2-devel for pkgconfig(glib-2.0) BuildRequires.
- Pass --with-package-name='openSUSE GStreamer package' and
  - -with-package-origin='http://download.opensuse.org' to configure
  we want to show where the gstreamer package is from.
- Pass  --disable-benchmarks, --disable-examples and
  - -disable-tests to configure, we do not need those.
- Move AUTHORS ChangeLog NEWS README RELEASE to doc subpackage.
* Thu Feb 23 2017 zaitor@opensuse.org
- Update to version 1.10.4:
  + Various fixes for crashes, assertions, deadlocks and memory
    leaks on fuzzed input files and in other situations
    (CVE-2017-5847, CVE-2017-5848).
  + More regression fixes for souphttpsrc redirection tracking.
  + Various bugfixes for regressions and other problems in the V4L2
    plugin.
  + Fix for 5.1, 6.1 and 7.1 channel layouts for Vorbis.
  + Bugs fixed: bgo#777998, bgo#778365.
- Drop gstreamer-parse-dont-translate-bin-name.patch: Fixed
  upstream.
* Sat Feb  4 2017 zaitor@opensuse.org
- Add gstreamer-parse-dont-translate-bin-name.patch: parse: Don't
  translate the "bin" element name. Otherwise we won't be able to
  create bins (bgo#777998).
* Mon Jan 30 2017 zaitor@opensuse.org
- Update to version 1.10.3:
  + CVE's fixed: CVE-2016-10198, CVE-2016-10199, CVE-2017-5837,
    CVE-2017-5838, CVE-2017-5839, CVE-2017-5840, CVE-2017-5841,
    CVE-2017-5842, CVE-2017-5843, CVE-2017-5844, CVE-2017-5845,
    CVE-2017-5846.
  + Bugs fixed: bgo#776125, bgo#775538, bgo#775661, bgo#775714,
    bgo#775728, bgo#775921, bgo#776039, bgo#776401, bgo#777263.
* Sat Dec  3 2016 zaitor@opensuse.org
- Update to version 1.10.2:
  + Minor bugfixes.
  + Updated translations.
* Sun Nov 27 2016 zaitor@opensuse.org
- Update to version 1.10.1:
  + Security-relevant bugfix in the vmnc decoder (no CVE).
  + Various bugfixes to playbin3/decodebin3.
  + Fix error at the end of playing any WAV file.
  + Fix usability of androidmedia plugin if the camera or sensor
    API is not available, but codecs are.
  + Handle redirections on PLAY, and missing control attribute in
    the RTSP source.
  + Various OpenGL related bugfixes and many, many more.
  + Bugs fixed: bgo#765662, bgo#773813, bgo#774044, bgo#774108.
* Wed Nov  2 2016 zaitor@opensuse.org
- Update to version 1.10.0:
  + Several convenience APIs have been added to make developers'
    lives easier.
  + A new GstStream API provides applications a more meaningful
    view of the structure of streams, simplifying the process of
    dealing with media in complex container formats.
  + Experimental decodebin3 and playbin3 elements which bring a
    number of improvements which were hard to implement within
    decodebin and playbin.
  + A new parsebin element to automatically unpack and parse a
    stream, stopping just short of decoding.
  + Experimental new meson-based build system, bringing faster
    build and much better Windows support (including for building
    with Visual Studio).
  + A new gst-docs module has been created, and we are in the
    process of moving our documentation to a markdown-based format
    for easier maintenance and updates.
  + A new gst-examples module has been create, which contains
    example GStreamer applications and is expected to grow with
    many more examples in the future.
  + Various OpenGL and OpenGL|ES-related fixes and improvements for
    greater efficiency on desktop and mobile platforms, and Vulkan
    support on Wayland was also added.
  + Extensive improvements to the VAAPI plugins for improved
    robustness and efficiency.
  + Lots of fixes and improvements across the board, spanning
    RTP/RTSP, V4L2, Bluetooth, audio conversion, echo cancellation,
    and more!
  + Bugs fixed: bgo#770627, bgo#772431, bgo#772571, bgo#772741,
    bgo#772851, bgo#773114, bgo#773319.
  + Updated translations.
- Add pkgconfig(libunwind) BuildRequires: New dependency.
- Add explicit pkgconfig BuildRequires for completeness.
* Mon Aug 22 2016 zaitor@opensuse.org
- Update to version 1.8.3 (boo#996937):
  + Fix stepping in PAUSED state in certain circumstances.
  + Fix jackaudiosink hang when exiting.
  + Fix udpsrc receiving multicast packets not only from the
    selected multicast group.
  + Fix unnecessary decoding of unselected streams in GES.
  + Fix (multi)udpsink randomly not sending to clients.
  + Fix ALL\_BOTH probes not considering EVENT\_FLUSH.
  + Fix average input rate calculations in queue2.
  + Fix various locking issues causing deadlock in adaptivedemux.
  + Fix gst-libav encoders to correctly produce codec\_data in
    caps.
  + Add Wayland, Windows and Rasberry Pi support to the QML GL
    video sink.
  + Add support for building with OpenH264 1.6.
  + Add support for controlling deinterlacing in GES video sources.
  + Bugs fixed: bgo#769802, bgo#768649, bgo#766970, bgo#768141,
    bgo#767688, bgo#763770, bgo#767413, bgo#739289, bgo#762330.
  + Updated translations.
- Drop separate spec file for gstreamer-doc. Due to this drop all
  conditionals for splitting out doc build. Also drop docbook-toys,
  docbook-utils, texlive-latex, texlive-latex-doc and transfig
  BuildRequires. Add doc subpackage to gstreamer spec and pass
  enable gtk-doc to configure. Note that we are building a much
  leaner doc package now.
- Following the above, drop pre_checkin script,
  gstreamer-no-gtk-doc-for-reals.patch and
  gstreamer-revert-bogus-automake-version.patch and stop passing
  NOCONFIGURE, no longer needed.
- Conditionally apply translations-update-upstream and
  gnome-patch-translation BuildRequires and macro for non-openSUSE
  only.
* Tue Jun 14 2016 zaitor@opensuse.org
- Update to version 1.8.2:
  + bgo#727105: doc: Drop reference to osssink / esdsink / etc,
    from gst-launch-1.0 man page.
  + bgo#741001: GST_DEBUG categories are missing when using
  - -gst-debug-help.
  + bgo#763496: queue: Can release serialized (ALLOCATION) query
    before downstream returned it.
  + bgo#765906: typefind: Regression due to fix for bgo#763491.
  + bgo#765961: Fix element leak in gstutils.c:find_common_root().
  + bgo#766002: pad: IDLE probes don't block when returning
    GST_PAD_PROBE_OK.
* Thu May 19 2016 alarrosa@suse.com
- Update to GNOME 3.20.2 (Fate#318572)
* Wed Apr 20 2016 zaitor@opensuse.org
- Update to version 1.8.1:
  + Fix app compilation with Android NDK r11 and newer.
  + Fix compilation of nvenc plugin against latest NVIDIA SDK 6.0.
  + Fix regression in avdeinterlace.
  + Fix memory corruption in scaletempo element with S16 input.
  + Fix regression in qtdemux with MSE streams.
  + Fix glitches at the start with all audio sinks except for
    pulsesink.
  + Fix regression with encrypted HLS streams.
  + Fix automatic multithreaded decoding of VP8/9 video.
  + Fix deadlock in HTTP adaptive streams when scrub-seeking.
  + Fix regression in RTSP source with SRTP.
  + Add support for SRTP rollover counters in the RTSP source.
  + Add support for HiDPI ("Retina") screens in caopengllayersink.
  + bgo#727105: doc: Drop reference to osssink / esdsink / etc,
    from gst-launch-1.0 man page.
  + bgo#741001: GST_DEBUG categories are missing when using
  - -gst-debug-help
  + bgo#761912: gstpad: Fix race between gst_element_remove_pad and
    state change.
  + bgo#762995: queue: Use full running time for level calculation.
  + bgo#763753: valve: don't send sticky events as a direct
    response to upstream events.
  + bgo#763757: multiqueue: Make sure mq- > percent remains valid
    after modifying high-percent value.
  + bgo#765096: baseparse: When initializing DTS from PTS, remember
    that we did so.
  + bgo#765260: baseparse: regression with aac streams.
  + Updated translations.
* Wed Apr 13 2016 idonmez@suse.com
- Update to GNOME 3.20  Fate#318572
* Sat Mar 26 2016 zaitor@opensuse.org
- Update to version 1.8.0:
  + Hardware-accelerated zero-copy video decoding on Android
  + New video capture source for Android using the
    android.hardware.Camera API.
  + Windows Media reverse playback support (ASF/WMV/WMA).
  + New tracing system provides support for more sophisticated
    debugging tools.
  + New high-level GstPlayer playback convenience API.
  + Initial support for the new Vulkan API, see Matthew Waters'
    blog post for more details.
  + Improved Opus audio codec support: Support for more than two
    channels; MPEG-TS demuxer/muxer can now handle Opus;
    sample-accurate encoding/decoding/transmuxing with Ogg,
    Matroska, ISOBMFF (Quicktime/MP4), and MPEG-TS as container;
    new codec utility functions for Opus header and caps handling
    in pbutils library. The Opus encoder/decoder elements were
    also moved to gst-plugins-base (from -bad), and the opus RTP
    depayloader/payloader to -good.
  + GStreamer VAAPI module now released and maintained as part of
    the GStreamer project.
  + Asset proxy support in the GStreamer Editing Services.
  + Bugs fixed: bgo#763491, bgo#763895, bgo#764034, bgo#763770.
- Rebase gstreamer-rpm-prov.patch, base on fedora patch.
* Thu Jan 21 2016 badshah400@gmail.com
- Update to version 1.6.3:
  + Fix regression in GL library that made glimagesink unsable
    on Android.
  + Integer arithmetic overflow in queue2 element that could
    break buffering or cause crashes due to NULL pointer
    dereference.
  + Fix crash in AAC/ADTS typefinder caused by reading more
    memory than is available.
  + Stop ignoring encoder errors in the VP8/VP9 encoders.
  + Deprecate GstVideoEncoder GST_VIDEO_ENCODER_FLOW_DROPPED.
    It's redudant and was never actually implemented.
  + Ensure to store the correct video info in
    GstVideoBufferPool.
  + Fix caps in rtspsrc when doing SRTP over interleaved TCP.
  + Fix crash in pcap parser on 0-sized packets.
  + Clear EOS flag in appsrc to allow reuse after EOS and
    flushing.
  + Ignore flushing streams in streamsynchronizer during stream
    switches to fix problems caused by this in
    gst-editing-services.
  + Ignore tags and other metadata in WAV files after the "data"
    chunk in PUSH mode to prevent them from being interpreted as
    audio.
  + Correctly use colorimetry in v4l2 only for YUV color
    formats.
  + Set reserved bits in MPEG TS muxer to 1s.
  + Fix calculation of SBC frame lengths.
  + Fix output of the RTP JPEG2000 depayloader to have one frame
    per buffer and crash in the OpenJPEG decoder on incomplete
    frames.
  + Update ffmpeg snapshot in gst-libav to 2.8.5.
  + Memory leak fixes in scaletempo, the raw video RTP
    depayloader, and in playsink related to audio/video filters.
  + Fixes for error handling in the OSX audio plugin.
  + Various gobject-introspection annotation fixes and
    additions.
  + Compiler warning fixes for latest clang compiler.
- Change source URL to http://gstreamer.freedesktop.org/ instead
  of http://download.gnome.org/; the former seems to be more
  frequently updated.
* Tue Jan 19 2016 meissner@suse.com
- Hook gst-ptp-helper helper into SUSE permissions framework
  (boo#960173):
  + Add permissions to requires(pre).
  + Add set_permissions to post and verify_permissions to
    verifyscript.
* Mon Jan 18 2016 dimstar@opensuse.org
- Adjustments post security review (boo#960173):
  + Add libcap-devel BuildRequires: rely on capabilities instead of
    flagging the binary suid.
  + Pass --with-ptp-helper-permissions=capabilities to configure:
    ensure there is no auto-fallback to attempting to install the
    binary suid in case capabilities would not work.
* Wed Dec 23 2015 dimstar@opensuse.org
- Update to version 1.6.2:
  + Crashes in gst-libav with sinks that did not provide a buffer
    pool but supported video metadata were fixed. This affected
    d3dvideosink and some 3rd party sinks. Also related fixes for
    crashes when a downstream buffer pool failed allocation.
  + Big GL performance improvement on iOS by a factor of 2 by using
    Apple's sync extension.
  + Deadlocks in the DirectSound elements on Windows, and the
    behaviour of its mute property were fixed.
  + The Direct3D video sink does not crash anymore when minimizing
    the window.
  + The library soname generation on Android >= 6.0 was fixed,
    which previously caused GStreamer to fail to load there.
  + File related elements have large-file (>2GB) support on Android
    now.
  + gst-libav was updated to ffmpeg 2.8.3.
  + Deserialization of custom events in the GDP depayloader was
    fixed.
  + Missing OpenGL context initialization in the Qt/QML video sink
    was fixed in certain situations.
  + Interoperability with some broken RTSP servers using HTTP
    tunnel was improved.
  + Various compilation fixes for Windows.
  + Various smaller memory leak and other fixes in different
    places.
  + Bugs fixed: bgo#734098, bgo#738292, bgo#741608, bgo#753823,
    bgo#755106, bgo#755222, bgo#755614, bgo#756028, bgo#756951,
    bgo#757155, bgo#757264, bgo#757453, bgo#757454, bgo#757732,
    bgo#757854, bgo#757873, bgo#757895, bgo#757924, bgo#757929,
    bgo#757935, bgo#758029, bgo#758151, bgo#758204, bgo#758205,
    bgo#758276, bgo#758285, bgo#758286, bgo#758337, bgo#758344,
    bgo#758512, bgo#758620, bgo#758861, bgo#758912, bgo#758913,
    bgo#758921, bgo#759019, bgo#759380.
- Add -fPIE to CFLAGS and -pie to LDFLAGS in order to ensure our
  executables are built position independent.
* Sat Oct 31 2015 zaitor@opensuse.org
- Update to version 1.6.1:
  + Valgrind 3.7.0 chokes on match-leak-kinds in gst.supp.
  + Gstreamer: Fix sample memory leaks.
  + gstreamer-1.6.0 doesn't compile on OS X 10.6: header file issue
    in gst-ptp-helper.c.
  + multiqueue: Improve incoming SEGMENT handling.
  + segment_to_stream_time and position_from_stream_time
    miscalculate when applied_rate < 0.
  + pad: gst_pad_probe_info_get_buffer_list() has wrong ownership
    transfer.
  + uri: incorrect behavior when merging uris ending in ..
  + pad: Unblock blocking pad probes when receiving FLUSH_START in
    send_event() too.
- Add gstreamer-revert-bogus-automake-version.patch: Upstream
  needed feature in automake 1.12, so for good measure they bumped
  to 1.14, this patch reverts this.
* Sat Sep 26 2015 zaitor@opensuse.org
- Update to version 1.6.0:
  + Stereoscopic 3D and multiview video support.
  + Trick mode API for key-frame only fast-forward/fast-reverse
    playback etc.
  + Improved DTS (decoding timestamp) vs. PTS (presentation
    timestamp) handling to account for negative DTS.
  + New GstVideoConverter API for more optimised and more correct
    conversion of raw video frames between all supported formats,
    with rescaling.
  + v4l2src now supports renegotiation.
  + v4l2transform can now do scaling.
  + V4L2 Element now report Colorimetry properly.
  + Easier chunked recording of MP4, Matroska, Ogg, MPEG-TS: new
    splitmuxsink and multifilesink improvements.
  + Content Protection signalling API and Common Encryption (CENC)
    support for DASH/MP4.
  + Many adaptive streaming (DASH, HLS and MSS) improvements.
  + New PTP and NTP network client clocks and better remote clock
    tracking stability.
  + High-quality text subtitle overlay at display resolutions with
    glimagesink or gtkglsink.
  + RECORD support for the GStreamer RTSP Server.
  + Retransmissions (RTX) support in RTSP server and client.
  + RTSP seeking support in client and server has been fixed.
  + RTCP scheduling improvements and reduced size RTCP support.
  + MP4/MOV muxer acquired a new "robust" mode of operation which
    attempts to keep the output file in a valid state at all times.
  + Live mixing support in aggregator, audiomixer and compositor
    was improved a lot.
  + Compositor now supports rescaling and converting inputs streams
    on the fly.
  + New audiointerleave element with proper input synchronisation
    and live input support.
  + Blackmagic Design DeckLink capture and playback card support
    was rewritten from scratch; 2k/4k support; mode sensing.
  + KLV metadata support in RTP and MPEG-TS.
  + H.265 video encoder (x265), decoders (libav, libde265) and RTP
    payloader and depayloaders.
  + New DTLS plugin and SRTP/DTLS support.
  + OpenGL3 support, multiple contexts and context propagation, 3D
    video, transfer/conversion separation, subtitle blending.
  + New OpenGL-based QML video sink, Gtk GL video sink,
    CoreAnimation CAOpenGLLayerSink video sink.
  + gst-libav switched to ffmpeg as libav-provider, gains support
    for 3D/multiview video, trick modes, and the CAVS codec.
  + GstHarness API for unit tests.
  + gst-editing-services got a completely new ges-launch-1.0.
    interface, improved mixing support and integration into
    gst-validate.
  + gnonlin has been deprecated in favor of nle (Non Linear Engine)
    in gst-editing-services.
  + gst-validate has a new plugin system, an extensive default
    testsuite, support for concurrent test runs and valgrind
    support.
  + cerbero build tool for SDK binary packages gains new
    'bundle-source' command.
  + Various improvements to the Android, iOS, OS X and Windows
    platform support.
- Drop gstreamer-message-delivery.patch: Fixed upstream.
- Add pkgconfig(bash-completion) BuildRequires: New dependency.
* Sun Mar  1 2015 dap.darkness@gmail.com
- Added gstreamer-message-delivery.patch
  to fix async message delivery, see more at
  http://cgit.freedesktop.org/gstreamer/gstreamer/commit/?id=da7847
* Fri Dec 26 2014 zaitor@opensuse.org
- Update to version 1.4.5:
  + Bugs fixed: bgo#736969, bgo#738092, bgo#740001.
  + Updated translations.
* Mon Nov 17 2014 zaitor@opensuse.org
- Revert previous bashish "ﬁxes", but specify in pre_checkin.sh
  and gstreamer.prov scripts that interpeter is #!/bin/bash.
* Mon Nov 17 2014 Led <ledest@gmail.com>
- fix bashism in pre_checkin.sh script
* Mon Nov 17 2014 Led <ledest@gmail.com>
- fix bashisms in gstreamer.prov script
* Fri Nov 14 2014 zaitor@opensuse.org
- Update to version 1.4.4:
  + Bugs fixed: bgo#737498, bgo#737794, bgo#737999, bgo#738198.
  + Updated translations.
* Wed Sep 24 2014 dimstar@opensuse.org
- Update to version 1.4.3:
  + Bugs fixed: bgo#709868, bgo#736969, bgo#737102, bgo#737133.
  + Updated translations.
* Sun Sep 21 2014 dimstar@opensuse.org
- Update to version 1.4.2:
  + Bugs fixed: bgo#735574, bgo#734412, bgo#735975, bgo#729811,
    bgo#736455, bgo#736424, bgo#736680, bgo#736295, bgo#736736,
    bgo#736739, bgo#736813, bgo#736762.
  + Updated translations.
* Thu Aug 28 2014 zaitor@opensuse.org
- Update to version 1.4.1:
  + Bugs fixed: bgo#732851, bgo#733805, bgo#733974, bgo#734688,
    bgo#734773.
  + Updated translations.
* Mon Jul 21 2014 dimstar@opensuse.org
- Update to version 1.4.0:
  + Bugs fixed: bgo#733131, bgo#733121, bgo#733320.
  + Updated translations.
* Thu Jul 17 2014 dimstar@opensuse.org
- Update to version 1.3.91:
  + Various API additions.
  + New plugins and elements:
  - v4l2videodec element for accessing hardware codecs on
    platforms that make them accessible via V4L2.
  - New downloadbuffer element that replaces the download
    buffering feature of queue2.
  - rtpstreampay and rtpstreamdepay elements for transmitting RTP
    packets over a stream API (e.g. TCP) according to RFC 4571.
  - rtprtx elements for standard compliant implementation of
    retransmissions, integrated into the rtpmanager plugin.
  - audiomixer element that mixes multiple audio streams together
    into a single one while keeping synchronization.
  - OpenNI2 plugin for 3D cameras like the Kinect camera.
  - OpenEXR plugin for decoding high-dynamic-range EXR images.
  - curlsshsink and curlsftpsink to write files via SSH/SFTP.
  - videosignal, ivfparse and sndfile plugins ported from 0.10.
  - avfvideosrc, vtdec and other elements were ported from 0.10
    and are available on OS X and iOS now.
  + Other changes:
  - gst-libav now uses libav 10.1, and gained support for
    H265/HEVC.
  - Support for hardware codecs and special memory types has been
    improved with bugfixes and feature additions in various
    plugins and base classes.
  - Various bugfixes and improvements to buffering in queue2 and
    multiqueue elements.
  - dvbsrc supports more delivery mechanisms and other features
    now, including DVB S2 and T2 support.
  - The MPEGTS library has support for many more descriptors.
  - Major improvements to tsdemux and tsparse, especially time
    and seeking related.
  - souphttpsrc now has support for keep-alive connections,
    compression, configurable number of retries and configuration
    for SSL certificate validation.
  - hlsdemux has undergone major refactoring and works more
    reliable now and supports more HLS features like trick modes.
  - dashdemux and mssdemux are now also pushing fragments
    downstream while they're downloaded instead of waiting for
    each fragment to finish.
  - videoflip can automatically flip based on the orientation
    tag.
  - openjpeg supports the OpenJPEG2 API.
  - waylandsink was refactored and should be more useful now.
  - gst-rtsp-server supports SRTP and MIKEY now.
  - gst-libav encoders are now negotiating any profile/level
    settings with downstream via caps.
  - Lots of fixes for coverity warnings all over the place.
  - Negotiation related performance improvements.
  - 800+ fixed bug reports.
  + Things to look out for:
  - The eglglessink element was removed and replaced by the
    glimagesink element.
  - The mfcdec element was removed and replaced by v4l2videodec.
  - osxvideosink is only available in OS X 10.6 or newer.
  - On Android the namespace of the automatically generated Java
    class for initialization of GStreamer has changed from
    com.gstreamer to org.freedesktop.gstreamer to prevent
    namespace pollution.
  - On iOS you have to update your gst_ios_init.h and
    gst_ios_init.m in your projects from the one included in the
    binaries if you used the GnuTLS GIO module before.
* Fri Apr 25 2014 dimstar@opensuse.org
- Update to version 1.2.4:
  + bgo#724373: Queue2 truncates its temp file when pipeline is
    paused.
  + bgo#725517: docs: Fix typos and remove unknown annotations.
  + bgo#725809: ghostpad: rare crash because of missing reference
    count on its target pad.
  + bgo#727253: parse: Bison generated file included in the release
    tarballs causes compile errors.
  + bgo#727883: baseparse: Memory leak of queue frames.
* Sun Feb  9 2014 zaitor@opensuse.org
- Update to version 1.2.3:
  + Bugs fixed: bgo#712597, bgo#719814, bgo#721253, bgo#721289,
    bgo#721300, bgo#721350, bgo#721422, bgo#721941, bgo#722467.
  + Updated translations.
* Tue Dec 31 2013 zaitor@opensuse.org
- Update to version 1.2.2:
  + Bugs fixed: bgo#712597, bgo#719437, bgo#707230, bgo#712300,
    bgo#714989, bgo#719575.
* Mon Nov 11 2013 dimstar@opensuse.org
- Update to version 1.2.1:
  + core: Fix max DEBUG_LEVEL incongruence on 5 vs 9.
  + Bugs fixed: bgo#709804, bgo#709637.
  + Updated translations.
* Tue Oct 22 2013 dimstar@opensuse.org
- Update to version 1.2.0:
  + A bunch of API changes (new stable branch 1.2).
  + New tool: gst-play-1.0 in gst-plugins-base for basic playback
    testing on the command line.
  + New plugins:
  - mssdemux for Microsoft Smooth Streaming.
  - dashdemux for DASH adaptive streaming protocol.
  - bluez for interaction with Bluetooth devices.
  - openjpeg for JPEG2000 decoding and encoding.
  - daala for experimental Daala decoding and encoding.
  - vpx plugin has experimental VP9 decoding and encoding
    support.
  - webp plugin for WebP decoding (encoding to be added later).
  - Various others: yadif, srtp, sbc, fluidsynth, midiparse,
    mfc, ivtv, accuraterip and audiofxbad.
  + Moved plugins: dtmf, vp8rtp, scaletempo and rtpmux plugins are
    now in gstreamer-plugins-good.
  + Audio and Video related fixes.
  + Other changes:
  - gst-libav now uses libav 9.
  - Static linking of plugins is supported now.
  - rtspsrc: add support for NetClientClock.
  - RTP retransmission / NACK support and big RTP jitterbuffer
    improvements.
  - SRTP and DTLS support.
  - Changes to many elements and core to use the correct sticky
    event order and also not lose any important sticky events
    during flushing.
  - >1000 fixed bug reports, and many other bug fixes and other
    improvements everywhere that had no bug report.
  + Notes:
  - Single header includes for all libraries,
    e.g. #include <gst/video/video.h>
  - Stricter (correct) caps subset checking in some cases.
  - x264enc now outputs data in byte-stream by default if
    downstream has ANY caps.
  - The MPEG TS demuxer posts messages contain the PMT, PAT,
    etc, in a different format now.
  - The GstContext API has changed between 1.1.4 and 1.1.90.
* Sat Aug 31 2013 zaitor@opensuse.org
- Update to version 1.0.10:
  + parse: make gst-launch syntax parser work with Bison 3.
  + memory: only copy the requested part instead of the complete
    source memory for default system memory.
  + queue2: update buffering when changing capacity.
  + g-i:
  - Add bindings-friendly buffer.extract() function.
  - Miscellaneous gobject-introspection annotation fixes
    (queries, pipeline).
  + Bugs fixed: bgo#705630, bgo#705678, bgo#705751, bgo#706462.
* Thu Aug 15 2013 zaitor@opensuse.org
- Update to version 1.0.9:
  + basesink: when we asynchronously go from READY to PLAYING, also
    call the state change function so that subclasses can update
    their state for PLAYING, esp. audio sinks added to the pipeline
    dynamically.
  + bindings: gobject-introspection annotation fixes.
  + Bugs fixed: bgo#702282.
* Sat Jul 13 2013 dimstar@opensuse.org
- Update to version 1.0.8:
  + basesink: improve position reporting without clock.
  + Fix caps leak in typefind/decodebin/playbin.
  + Gobject-introspection fixes for bindings.
  + Bugs fixed: bgo#693365, bgo#702617, bgo#702778, bgo#703562.
* Sat Apr 27 2013 dimstar@opensuse.org
- Update to version 1.0.7:
  + Add better support for static plugins.
  + Bugs fixed: bgo#667305, bgo#696357, bgo#696435, bgo#697791.
* Sat Mar 23 2013 zaitor@opensuse.org
- Update to version 1.0.6:
  + bin: reset GValue from iterator after usage, fixing leak.
  + pipeline: fix seeking on pipeline with NULL clock.
  + message: accept NULL error argument in
    gst_message_parse_{error,warning,info}.
  + basesrc: handle renegotiation correctly.
  + basesink: handle sync of EOS after item without duration.
  + basetransform: avoid warnings from NULL outcaps passed to
    transform_size in shutdown race.
  + adapter, basesrc, typefind: handle gst_buffer_map failure.
  + queuearray:
  - fix gst_queue_array_drop_element().
  - fix gst_queue_array_find().
  + queue: remove query from queue if queue is flushing.
  + g-i:
  - make sure enumeration types and flags are introspected and
    available to bindings.
  - add allow-none annotation for gst_pipeline_new()'s name
    property.
  + Bugs fixed: bgo#684804, bgo#691185, bgo#691985, bgo#691986,
    bgo#692691, bgo#692868, bgo#693065, bgo#693587, bgo#693704,
    bgo#693996.
* Mon Feb 25 2013 sbrabec@suse.cz
- Added support for gnome-patch-traslation.
* Sat Jan 19 2013 dimstar@opensuse.org
- Update gstreamer-rpm-prov.patch: PackageKit is looking for
  packages with gstreamer(*) provides.. so we should provide the
  same.
* Wed Jan  9 2013 dimstar@opensuse.org
- Update to version 1.0.5:
  + Add GST_BIN_FLAG_NO_RESYNC flag that disables a resync when an
    element is added, removed or linked in the bin.
  + Add OTHER clock type
  + Bugs fixed: bgo#690915.
* Wed Dec 19 2012 dimstar@opensuse.org
- Update to version 1.0.4:
  + basesrc: fix potential leaks when re-activating in a different
    mode
  + bindings:
  - make all pad probe types work with bindings
  - fix gst_event_parse_stream_start() annotation, fixing crash
  + Documentation improvements.
  + Bugs fixed: bgo#687845, bgo#688804, bgo#688934.
* Thu Nov 22 2012 dimstar@opensuse.org
- Update to version 1.0.3:
  + bufferpool: fix deadlock.
  + baseparse: forward stream-start event in push mode, fixing
    issues with streamsynchronizer
  + basesink: reset START_TIME when needed, fixing position
    reporting after seeking beyond end
  + Bugs fixed: bgo#666053, bgo#687896, bgo#688477, bgo#688511,
    bgo#688655, bgo#685870.
* Thu Oct 25 2012 dimstar@opensuse.org
- Update to version 1.0.2:
  + Parallel installability with 0.10.x series
  + collectpads: ensure all timestamps are in same time domain
  + gobject-introspection: fix GstSample annotations
  + add GstElement::post_message() vfunc
  + info: allow gst_debug_add_log_function() to be called before
    gst_init()
  + event: allow GST_CLOCK_TIME_NONE as duration for GAP events
  + documentation: new chapters and updates for the application
    development manual and the plugin writer's guide
  + Bugs fixed: bgo#686456, bgo#686658, bgo#686659, bgo#686723,
    bgo#686787.
* Tue Oct  9 2012 dimstar@opensuse.org
- Update to version 1.0.1:
  + Capsfilter prefers filter caps over passthrough now
  + Application Development Manual, Plugin Writer's Guide and other
    documentation updated and extended for 1.0
  + Bugs fixed: bgo#680862, bgo#684538, bgo#684755, bgo#684765,
    bgo#684809, bgo#684970, bgo#684981, bgo#685072.
* Mon Sep 24 2012 dimstar@opensuse.org
- Update to version 1.0.0:
  + Minor bugfixes
  + Updated documentation.
* Tue Sep 18 2012 dimstar@opensuse.org
- Update to version 0.11.99:
  + Minor fixes
  + Remove GST_USE_UNSTABLE_API guard and defines.
* Fri Sep 14 2012 vuntz@opensuse.org
- Revert change from Sept 2nd: we'll actually rename things in
  gstreamer-0_10 instead, since that's the package which is
  versioned.
- Update gstreamer-rpm-prov.patch: we need to output gstreamer1.0()
  instead of gstreamer0.10() for the Provides.
- Version the gstreamer-utils Requires in devel subpackage, to
  avoid having a choice between the 0.10 package and this one.
* Fri Sep 14 2012 dimstar@opensuse.org
- Update to version 0.11.94:
  + gstcompat: fix backwards compat macro for
    gst_message_new_duration
  + baseparse:
  - Add a mode/flag for disabling PTS interpolation
  - Handle GAP and still-frame events
  - Restructure event handling
  - Store incoming cached events in reverse order
  - First attempt at handling both DTS and PTS
  + taglist:
  - add warning when we get something else than a sample for a
    sample tag
  + elementfactory:
  - don't crash if no element klass has been set(bgo#683865)
  + Updated documentations
  + Bugs fixed: bgo#581525, bgo#599546, bgo#608841, bgo#634927,
    bgo#645467, bgo#647759, bgo#657202, bgo#657640, bgo#657725,
    bgo#667293, bgo#672637, bgo#673319, bgo#673641, bgo#676935,
    bgo#677620, bgo#677621, bgo#677757, bgo#677818, bgo#677819,
    bgo#677898, bgo#677925, bgo#678017, bgo#678031, bgo#678181,
    bgo#678301, bgo#678742, bgo#678928, bgo#679080, bgo#679112,
    bgo#679145, bgo#679286, bgo#679378, bgo#679407, bgo#679506,
    bgo#679534, bgo#679535, bgo#680181, bgo#680306, bgo#680479,
    bgo#680495, bgo#680755, bgo#680796, bgo#680804, bgo#680805,
    bgo#681139, bgo#681153, bgo#681198, bgo#681322, bgo#681450,
    bgo#681575, bgo#681681, bgo#682958, bgo#682968, bgo#682997,
    bgo#683470, bgo#683865.
- Rebase gstreamer-rpm-prov.patch.
* Sun Sep  2 2012 dimstar@opensuse.org
- Make gstreamer 1.0 and 0.10 -devel parallel installable:
  + Rename gstreamer.attr to gstreamer1.attr
  + Rename gstreamer-provides to gstreamer-provides1
* Wed Aug  8 2012 dimstar@opensuse.org
- Update to version 0.11.93:
  + added scope to taglists and TOCs (stream or global)
  + countless gobject-introspection annotation fixes
  + GstMiniObject: add qdata() (for object-private data)
  + basesink now prerolls on GAP event
  + versioned variants of environment variables
  + major low-level GstMemory reworking
  + allow mini objects to be LOCKABLE for
    read/write/exclusive access, use this
    in GstMemory
  + add segment-done event in addition to segment-done message
  + make allocation query more extendable
  + send STREAM_START events and STREAM_START message
  + remove gst_tag_list_get_buffer(), add gst_tag_list_get_sample()
    and move tags of GST_TYPE_BUFFER to GST_TYPE_SAMPLE, esp.
    GST_TAG_IMAGE and GST_TAG_PREVIEW_IMAGE, also
    GST_TAG_ATTACHMENT and GST_TAG_APPLICATION_DATA
  + GstDateTime: add support for partial date times where not
    all fields are set
  + move DATE tag from GDate to GstDateTime (for partial dates)
  + major TOC API reworking, make TOC events sticky
  + audio/video base class fixes and some minor API changes
    (e.g. frame refcounting; negotiation; propose_allocation)
  + port GstVideoOverlayComposition to 0.11, add GstMeta for it
  + fixes everywhere, esp. playback-related (demuxers, decoders,
    parsers)
* Tue Jul 17 2012 dimstar@opensuse.org
- Update to version 0.11.92:
  + Parallel installability with 0.10.x series.
  + API cleanup and minor API improvements.
  + GstTagList is a refcounted type now.
  + Lots of bugfixes, cleanup and other improvements.
- Rebase gstreamer-rpm-prov.patch.
- Update gstreamer.prov to actually call gst-inspect-1.0.
* Mon May 14 2012 vuntz@opensuse.org
- Update to version 0.11.91:
  + API cleanup and minor improvements
  + More hiding of structs that don't need to be public
  + Addition of SNAP flag for seek events
* Fri Apr 20 2012 vuntz@opensuse.org
- Update to version 0.11.90:
  + Lots of bugfixes, cleanup and other improvements
  + Improvements to the buffer and memory managment API
  + A new GstTOC interface, e.g. for handling chapters
  + The GstChildProxy interface works with any GObject now
- Rebase gstreamer-no-gtk-doc-for-reals.patch.
- Rename libgstreamer-0_11-0 to libgstreamer-1_0-0 following
  upstream soname change.
- Rename typelib-1_0-Gst-0_11 to typelib-1_0-Gst-1_0 following
  upstream typelib name change.
* Fri Mar 23 2012 vuntz@opensuse.org
- Update to version 0.11.3:
  + Various bug fixes and improvements
  + Input-selector defaults to sync-streams=true
  + Queue don't just start the thread on linking
  + Add user_data and notify to gst_memory_new_wrapped()
  + Rework caps function for performance
  + Improve basetransform allocator handling
  + Implement metadata transforms
  + Metadata registration improvements
  + Use generic marshallers everywhere
  + Push Sticky events in more cases
  + Register queries like events
  + Add DRAIN serialized query
  + Add 0-padding and prefix to GstMemory
  + Rework the ALLOCATION query
  + Allow setting the allocator in a bufferpool
  + Improve pull/get_range
* Fri Feb 17 2012 dimstar@opensuse.org
- Update to version 0.11.2:
  + Added pts/dts to buffers
  + Moved controller into core
  + Pad probe rewrite
  + AcceptCaps and GetCaps made as queries
  + Added parent to pad functions
  + Sticky events rewrite
  + New GstSample object
  + Asynchronous state change support for basesrc
  + Added new bitmask type
  + GstMemory updates
  + Port to gio
  + Port to newest glib
  + Add stepped ranges
  + Do typefind in separate thread
  + Rework alloc tracing
  + Added STREAM_CONFIG, GAP and STREAM_START events
  + Various cleanups and leak fixes
- Rebase gstreamer-rpm-prov.patch.
* Tue Jan 24 2012 vuntz@opensuse.org
- Update to version 0.11.1:
  + Remove negotiation from state change in GstBaseSrc
  + Removed our custom FOURCC type
  + Updates to the base classes
* Sat Jan 21 2012 zaitor@opensuse.org
- Add libtool as explicit buildrequire to avoid implicit dependency
  from prjconf.
- Split typelib files into typelib-1_0-Gst-0_11 subpackage.
- Add typelib-1_0-Gst-0_11 Requires to devel subpackage.
- Add explicit libgstreamer-0_11-0 Requires to devel subpackage: it
  was there implicitly before, through the gstreamer
  Requires, but it's better to have it explicit.
- Add gstreamer-utils Requires to devel subpackage: it is needed
  for automatic provides rpm magic.
- Remove explicit check-devel, glib2-devel, libxml2-devel and
  popt-devel Requires from devel subpackage: the ones that are
  needed will be added the pkgconfig() way, and the others are
  actually wrong.
* Wed Aug  3 2011 dimstar@opensuse.org
- Update to version 0.11.0:
  + Reworked buffer memory management
  + Arbitrary buffer metadata
  + Integrated bufferpool management
  + Improved dynamic pipeline changes
  + Reworked video caps system
  + Reworked pad probes
- Clean spec-file using spec-cleaner.
- Rename package to gstramer-0_11:
  + Remove the old gstreamer010 provides and obsoletes. They are
    no longer true.
  + Rename all subpackage accordingly
  + Adjust baselibs.conf
* Fri Jun 17 2011 dimstar@opensuse.org
- Update to version 0.10.35:
  + Work around GLib atomic ops API change
  + Some minor win32/mingw fixes
  + Don't use G_CONST_RETURN in public headers (bgo#652211)
* Thu May 19 2011 mls@suse.de
- move gstreamer deps generator definition from rpm into
  the gstreamer-0.10-devel package
* Wed May 18 2011 dimstar@opensuse.org
- Update to version 0.10.34:
  + Fix multiqueue thread-safety regression
  + Don't set artificial 0-timestamp on first packet for TIME-based
    live sources
  + Bugs fixed: bgo#649369, bgo#649878.
* Wed May 11 2011 dimstar@opensuse.org
- Update to version 0.10.33:
  + atomicqueue: add an atomic/lock-free queue structure based
  + bufferlist: improve _add*() performance
  + bus: in _add_watch() honour any per-thread default main context
    set via g_main_thread_push_thread_default()
  + caps: new gst_caps_intersect_full() to intersect in different
    modes
  + clock: add functions to re-init existing periodic GstClockIDs
  + event: add QoS type (overflow, underflow, throttle) for QoS
    events
  + ghostpad: The internally linked pad of the proxypad is the
    ghostpad
  + gstpoll: retry reading the control socket to release properly
    all wakeups
  + message: new progress message API for asynchronous operations
  + pad:
  - unlock before freeing the pad cache to avoid deadlock
  - better handling for when parent goes away during
    data/query/event flow
  + parse-launch: allow element names to begin with digits
  + pluginloader: call gst-plugin-scanner with the right arch on
    OSX, fixing hangs with firefox
  + registry: fixes elements (features) disappearing if a plugin or
    plugin file is renamed
  + structure:
  - Add "(date)" as a type abbreviation of GDate
  - Don't allow invalid GDates in all structures and don't allow
    NULL GDates in taglists
  + taglist: add a new "encoded-by" tag
  + uri: add gst_filename_to_uri() that takes relative filenames
  + utils: add gst_element_factory_can_{src|sink}_{any|all}_caps()
    to replace can_{sink,src}_caps()
  + baseparse: new GstBaseParse class for parsers
  + basesink:
  - improve rate, duration, and average duration calculation
  - use new QoS types and add add "throttle-time" property
  + basesrc:
  - Handle tag and custom downstream events the same
  - keep downstream caps order when fixating, to honour
    downstream preferences when negotiating
  - Return FALSE if we don't handle an event
  - Send synchronized custom downstream/both events downstream
    from the streaming thread
  + basetransform:
  - Be smarter with pad allocs
  - Check for pad alloc caps when suggestion is not fixed
  - Retain caps order when getting caps, to honour downstream
    preferences when negotiating
  + funnel: new N-to-1 pipe fitting element imported from farsight
  + fakesink:
  - print buffer flags
  - Fix escaping of URIs
  + file{sink,src}:
  - Check if non-URI characters are escaped, but only for the URI
    not the location property
  - fix URI creation regression for non-absolute locations
  + filesrc: Fix escaping of file uris
  + inputselector:
  - Hold the selector lock while reading properties of the active
    pad
  - Make sure that EOS is always sent downstream for the active
    pad
  - Return GST_FLOW_OK until the selected pad pushed something
    downstream
  - Stop waiting for a pad switch when the pad is flushing
  + multiqueue:
  - fix some potential corner-case deadlocks and some leaks
  - handle arbitrary sink + source pad naming
  + queue2: don't read beyond the end of file upstream in pull
    mode; leak fixes
  + plugins: make query and event functions more thread-safe,
    protect against parent-pad disappearing
  + gst-launch: add GstIndex support
  + Bugs fixed: bgo#642356, bgo#402141, bgo#518857, bgo#604094,
    bgo#615357, bgo#617045, bgo#639674, bgo#639962, bgo#640071,
    bgo#640437, bgo#640502, bgo#640622, bgo#640675, bgo#640850,
    bgo#641212, bgo#641928, bgo#642071, bgo#642130, bgo#642271,
    bgo#642373, bgo#642393, bgo#642504, bgo#642522, bgo#642869,
    bgo#643301, bgo#643455, bgo#644935, bgo#645022, bgo#645267,
    bgo#645595, bgo#645746, bgo#645877, bgo#645931, bgo#646118,
    bgo#646341, bgo#646531, bgo#646566, bgo#646569, bgo#646624,
    bgo#646811, bgo#646971, bgo#647005, bgo#647131, bgo#647293,
    bgo#647763, bgo#647844, bgo#647922, bgo#648199, bgo#648215,
    bgo#648220, bgo#648297, bgo#649195, bgo#635718, bgo#625396,
    bgo#640771, bgo#646972, bgo#640665.
- Rebase gstreamer-0_10-rpm-prov.patch.
* Tue May  3 2011 dimstar@opensuse.org
- Extend gstreamer-0_10-rpm-prov.patch: Also provide elements.
* Tue Jan 25 2011 wstephenson@novell.com
- Update to version 0.10.32
  + GLib requirement is now >= 2.22
  + New core elements:
  - valve (moved from -bad)
  - input-selector (N.B. without "select-all" property, use fsfunnel
    instead) (moved from -bad)
  - output-selector (with different negotiation behaviour by
    default, set pad-negotiation-mode=active for previous behaviour)
    (moved from -bad)
  + Performance improvements for many heavily-used code paths:
    GstPad, GstPoll, GstClock, GstTask, basesink, basesrc, queue2,
    multiqueue
  + gobject-introspection: add annotations for most core API
  + clock: make sync clock wait lockfree
  + fdsrc/fdsink: reenable on MSVC
  + registry: fix GStatBuf definition for win32 when building against
    older glib (fixes unnecessary rescanning of plugins at start-up)
  + element: add a more flexible way to get request pads from elements
  + multiqueue: return upon input when already eos
  + object: fix creation of default name
    (when creating more than 100000 elements)
  + pluginloader: fix hangs on OSX
  + poll:
  - fixes for (p)select backend (used e.g. on OSX)
  - refactor and make more lockfree; fixes for win32 and OSX
    (pselect backend)
  + registry: don't replace valid existing plugins by blacklisted ones
  + tags: don't produce duplicated entries when merging same value twice
  + basesink:
  - preroll fixes for async=false case
  - rework position reporting code
  + basetransform: handle downstream giving a buffer with new caps
    but invalid size
* Sun Jan 16 2011 aj@suse.de
- Remove buildrequire on pyxml and add python instead for doc
  package only, changelog of package with date 2008-03-21 contains:
  "Don't depend on PyXML and use only XML modules that are shipped
  with python."
* Tue Dec  7 2010 vuntz@opensuse.org
- Update to version 0.10.31:
  + bin:
  - add "message-forward" property to force forwarding of
    messages that would usually be filtered such as ASYNC_DONE or
    EOS
  - improve tracking of source elements for more efficient event
    dispatch
  + bufferlist: add function to add a list of buffers
  + clock: fix racy shutdown clock id leak
  + element:
  - add support for arbitrary element class / factory details
  - link_many should activate pads if needed
  + gst: add math-compat.h header
  + datetime: add GstDateTime API
  + elementfactory: add utility functions to filter features by
    type
  + plugin: load the gst-python plugin loader with
    G_MODULE_BIND_LAZY
  + query: add buffering ranges API to retrieve informations about
    the areas of the stream currently buffered
  + value: add int64 range type
  + info: write debugging output to file if GST_DEBUG_FILE
    environment variable is set
  + pad: use more efficient g_object_notify_by_pspec() for caps
    notifies if compiling against new-enough GLib
  + pipeline: If the currently used clock gets lost update it the
    next time when going from PAUSED to playing
  + plugin: add release datetime field to GstPluginDesc and set it
    if GST_PACKAGE_RELEASE_DATETIME is defined
  + utils: speed up pad linking utility functions by not trying
    pads that will never work
  + adapter:
  - add function to get a list of buffers; support 0-sized
    buffers
  - optimize gst_adapter_take() and gst_adapter_peek() a little
  + basesink: only answer the SEGMENT query in pull mode
  + basesrc: return values in stream time for the POSITION query
  + basetransform:
  - allow the subclass to add new fields to caps when getting new
    caps from downstream
  - avoid useless memcpy
  - upstream caps-renegotiation fixes
  + bitreader: add inlined and unchecked versions of the most
    important functions
  + bytewriter:
  - add inline and unchecked variants of all important functions
  - fix possible infinite loop caused by an overflow
  + queue:
  - add "silent" property to suppress signal emission (for better
    performance)
  - avoid unnecessary g_cond_signal() (for better performance)
  - push newsegment event when linking in PLAYING
  + queue2:
  - extend ring buffer to support RAM mode
  - in download mode, prevent range corruption due to race
  - don't send seeks beyond the end of the file upstream in pull
    mode (fixes apple trailers and youtube/html5 playback in
    webkit)
  + multiqueue: flush the data queue if downstream return
    WRONG_STATE too
  + gst-inspect: print GST_PARAM_MUTABLE_* property flags
  + See NEWS for API additions and deprecations.
  + Bugs fixed: bgo#396774, bgo#482147, bgo#579127, bgo#594504,
    bgo#600004, bgo#610366, bgo#611918, bgo#618919, bgo#619522,
    bgo#621299, bgo#621332, bgo#622740, bgo#623040, bgo#623121,
    bgo#623491, bgo#623541, bgo#623622, bgo#623806, bgo#623875,
    bgo#624203, bgo#625239, bgo#625295, bgo#625368, bgo#625862,
    bgo#626027, bgo#626181, bgo#626651, bgo#626784, bgo#627438,
    bgo#627826, bgo#627910, bgo#627959, bgo#628014, bgo#628174,
    bgo#628176, bgo#628408, bgo#629241, bgo#629410, bgo#629494,
    bgo#629553, bgo#629831, bgo#629946, bgo#630257, bgo#630436,
    bgo#630437, bgo#630439, bgo#631755, bgo#631853, bgo#632236,
    bgo#632433, bgo#632977, bgo#633147, bgo#633886, bgo#635031,
    bgo#635389, bgo#635869, bgo#633176.
- Drop gstreamer-0_10-make382.patch: fixed upstream.
* Sat Sep 18 2010 vuntz@opensuse.org
- Move gir files to devel subpackage.
* Wed Sep 15 2010 dimstar@opensuse.org
- Extend gstreamer-0_10.prov: we need a possibility to simply skip
  the automatic provides function. In this case, defining
  SKIP_GSTPROVIDES to non-zero will be recognized as an ignore flag
  for the package. All other requires/provides will not be
  affected.
* Sat Sep 11 2010 dimstar@opensuse.org
- Add gstreamer-0_10-make382.patch: Fix build with make 3.82.
  Generally, the -doc package is affected.
* Thu Sep  2 2010 dimstar@opensuse.org
- Add gstreamer-0_10-rpm-prov.patch: adds --rpm to gst-inspect,
  allowing rpm to create a list of provides, thanks to the
  gstreamer-0_10.prov script we install. Those provides can then be
  picked up by PackageKit. Patch taken from Fedora's gstreamer
  package.
- Add gstreamer-0_10.macros that contains a rpm macro, in case
  external provides scripts are used.
- Add gstreamer-utils Requires to the -devel package: this is used
  in gstreamer-0_10.prov for the rpm magic to work.
* Tue Aug 31 2010 aj@suse.de
- Recommend instead of require lang package since it's not mandatory.
* Tue Aug 31 2010 aj@suse.de
- Recommend instead of require lang package since it's not mandatory.
* Thu Jul 29 2010 dimstar@opensuse.org
- Update to version 0.10.30:
  + bgo#623586: gst/tagsetter check fails
  + bgo#463435: Skip #include < libxml/parser.h > in gstconfig.h.in
    when not needed
  + bgo#505770: gst_element_get_state() should unblock if element
    posts an error
  + bgo#615820: implement percentage position and duration queries
  + bgo#615941: [tags] Add GST_TAG_DEVICE_MANUFACTURER and
    GST_TAG_DEVICE_MODEL
  + bgo#616586: Use GObject's boxed type for GError
  + bgo#617223: [tags] Add tags for direction of capture and
    movement
  + bgo#617625: Commandline utility wrappers (gst-run) don't work
    on Windows
  + bgo#618644: gst_pad_get_caps() Return pad template if parent
    element is in GST_STATE_NULL
  + bgo#619508: [tag] Add image orientation tag
  + bgo#619815: GST_PLUGIN_LOADING_WHITELIST env var for unit tests
  + bgo#619828: [API] adapter: add masked_scan_uint32_peek
  + bgo#620460: info: add new TRACE log level and move refcounting
    there from LOG level
  + bgo#620490: [basesink] segment query unconditionally returns
    FALSE
  + bgo#621006: Deprecate unused gst_object_{get|set}_name_prefix()
  + bgo#621282: Display of short fourccs is in hex instead of text
  + bgo#621332: BaseTransform should disable proxy alloc if
    downstream changes caps
  + bgo#621334: GstBaseTransform should not require a
    transform_size function
  + bgo#621505: Disable memory poisoning by default for releases
  + bgo#621527: gstcaps: New gst_caps_steal_structure() method
  + bgo#621530: filesink ignores sync=true
  + bgo#621595: --quiet doesnt make gst-launch be completely quiet,
    also messages should not go to stdout
  + bgo#621773: Add introspection annotations
  + bgo#621867: gst-launch: rename new --no-play command line
    option
  + bgo#621896: [API][taglist] Add gst_tag_list_peek_string_index
  + bgo#622504: [GstPad] Provide more fine-grained linking methods
  + bgo#622546: distcheck fails in docs/plugins/
  + bgo#622685: [GstXml] Deprecate GstXml
  + bgo#622967: [queue2] Problems with progressive downloading
  + bgo#623301: gst_caps_normalize: doesn't normalize completely
  + bgo#623589: Fix races/refcounting bugs with slave clocks
  + bgo#624113: [tags] wrong behaviour in merge function for
    strings
  + bgo#622025: Can't build gstreamer due to Gst-0.10.gir: error:
    Can't resolve type 'PadIntLinkFunction' for field
    Gst.Pad.intlinkfunc
* Tue May  4 2010 dimstar@opensuse.org
- Update to version 0.10.29:
  + improve plugin loading robustness: do not ever unload a plugin
    after calling into it: should fix mystery crashers during
    registry loading when a plugin init function returns FALSE
    (e.g. when some supporting library fails to initialise or a
    wrapper plugin found no features to wrap and wrongly returned
    FALSE)
  + configurable memory alignment for GstBuffers
  + add QoS message to inform apps of lost data, dropped frames etc
  + basesink, basetransform: add support for new QoS message
  + basetransform: accept non-fixed caps suggestions
  + basesrc: fix gst_base_src_new_seamless_segment()
  + GstController fixes and optimisations
  + set thread name for pad tasks on Linux
  + pipeline, bin: fix refcount issue when removing elements during
    a state change
  + queue2: implement seeking in download mode
  + queue2: implement flushing in download buffering
  + queue2: improve buffer level measurement in download mode
  + fdsrc: allow specifying the size in bytes on the uri
  + build fixes: better checks for uint128_t, inline assembly on
    OSX, compilation if HAVE_REGISTER_PRINTF_SPECIFIER is
    undefined, gobject-introspection
  + two symbols were removed that had been exported but never been
    used or been declared in any header file:
    gst_element_default_error & gst_element_request_compatible_pad.
- Drop gstreamer-0_10-fix-introspection-build.patch: upstreamed.
- Rebase gstreamer-0_10-no-gtk-doc-for-reals.patch.
* Sat Mar 13 2010 dimstar@opensuse.org
- Update to version 0.10.28:
  + No material changes compared to 0.10.27, this release is mostly
    to keep the version in sync with gst-plugins-base
  + Parse "1/MAX" fraction strings .
* Mon Mar  8 2010 dimstar@opensuse.org
- Update to version 0.10.27:
  + bgo#610366: [gstcollectpads][doc] Add a reminder for 'data' doc
  + bgo#605189: gst_element_get_state has wrong introspection
  + bgo#607771: [API] Add gst_byte_writer_fill
  + bgo#608036: [typefind] deadlock when upstream puts caps on
    buffers on pull mode
  + bgo#608877: [typefind] Access to internal fields not threadsafe
  + bgo#609941: GStreamer-WARNING **: External plugin loader failed
  + bgo#610210: [PATCH] Fix compilation of fdsink and fdsrc with
    MSVC
  + bgo#610246: [optimization] Speed up _get_range()
  + bgo#610367: [memindex] might busy loop upon EXACT lookup
  + bgo#610444: [controller] Interpolation control source passes
    NULL pointers to GSequence API
  + bgo#611087: [basesink] emergency rendering of late buffers
    fails after resuming from PAUSE
  + bgo#611719: GST_DEBUG_OBJECT macros not fed with GObject* in
    gstpoll.c
  + API additions:
  - gst_byte_writer_fill()
* Fri Feb 12 2010 dimstar@opensuse.org
- Update to version 0.10.26:
  + Changes:
  - registry: do plugin scanning (on *nix) using an external
    helper binary
  - lots of performance improvements all over the place
  - add GstByteWriter, a simple generic byte writer
  - filesink: Use _wfopen on win32 to open files with non-ascii
    filenames correctly.
  - queue2: add option to remove the temp-file (enabled by
    default)
  - it is now allowed to use gst_caps_set_simple() on non-simple
    caps
  - queue2: move from gst-plugins-base into the coreelements
    plugin in core
  - multiqueue: add support for buffering mode where we post
    BUFFERING messages based on the level of the queues
  - typefind: speed up typefinding a lot by first trying the
    typefinder for the file's extension
  - buffer: remove private/internal subbuffer subclass and keep
    track of the parent buffer directly in the GstBuffer
    structure
  - collectpads: add ability to install clipping functions
  - new tags for TV/Radio shows/episodes, lyrics, composer
    sortname and grouping
  - miniobject: avoid race when recycling buffers
  - basesrc: fix race in PLAYING->PAUSED->PLAYING
  + Bugs fixed: bgo#476514, bgo#590941, bgo#595602, bgo#535069,
    bgo#560442, bgo#595511, bgo#595886, bgo#595964, bgo#596366,
    bgo#597407, bgo#597550, bgo#597690, bgo#598297, bgo#598526,
    bgo#598700, bgo#598895, bgo#598896, bgo#599147, bgo#599759,
    bgo#600313, bgo#600922, bgo#601587, bgo#601668, bgo#601669,
    bgo#602093, bgo#602275, bgo#602419, bgo#603059, bgo#603787,
    bgo#604091, bgo#604093, bgo#605251, bgo#605930, bgo#606435,
    bgo#607283, bgo#607317, bgo#607431, bgo#607481, bgo#607739,
    bgo#607842, bgo#608136, bgo#608398, bgo#608442, bgo#608726,
    bgo#609166, bgo#590669, bgo#601698, bgo#604565, bgo#596877
  + API additions, see NEWS.
* Wed Jan  6 2010 jengelh@medozas.de
- Package baselibs.conf
* Thu Dec  3 2009 vuntz@opensuse.org
- Compile introspection support:
  + Add gobject-introspection-devel BuildRequires.
  + Pass --enable-introspection to configure.
  + Add gstreamer-0_10-fix-introspection-build.patch to fix the
    build.
- Small cleanups.
* Mon Nov 16 2009 lmedinas@opensuse.org
- Update to version 0.10.25:
  + Changes:
  - Improve the byte-reader API
  - GObject introspection support
  - Improve clock accuracy on win32
  - Optimisations in capabilities checking
  - Optimisations and fixes in the basetransform base class
  - New 64-bit scaling utility function variants
  - Various bug-fixes and improvements
  + Bugs fixed: bgo#583999, bgo#566881, bgo#588472, bgo#589173,
    bgo#589314, bgo#589524, bgo#589849, bgo#589991, bgo#590045,
    bgo#590430, bgo#590841, bgo#590919, bgo#591045, bgo#591318,
    bgo#591441, bgo#592209, bgo#592314, bgo#593460, bgo#593719,
    bgo#594107, bgo#594225, bgo#594990, bgo#595130, bgo#595133,
    bgo#595209, bgo#368536
* Mon Oct 26 2009 sbrabec@suse.cz
- Added support for translation-update-upstream (FATE#301344).
* Wed Aug 12 2009 sbrabec@suse.cz
- Create empty /usr/share/gstreamer-0.10/presets for presets.
* Wed Aug  5 2009 vuntz@novell.com
- Update to version 0.10.24:
  + Changes:
  - Fully support nested structures in caps
  - Support frame-by-frame stepping in sinks
  - Add support for buffer-lists to pass around groups of buffers
  - Use TaskPools for managing worker threads
  - New stream-status API for finer thread control
  - Code optimisations
  - Many other bug-fixes and enhancements
  + Bugs fixed: bgo#580579, bgo#527488, bgo#570233, bgo#584389,
    bgo#534208, bgo#545787, bgo#554460, bgo#559643, bgo#560345,
    bgo#560442, bgo#572285, bgo#577926, bgo#578908, bgo#580177,
    bgo#580716, bgo#581198, bgo#581281, bgo#582010, bgo#582564,
    bgo#582588, bgo#582878, bgo#583187, bgo#583419, bgo#583456,
    bgo#583554, bgo#584835, bgo#584838, bgo#585039, bgo#585075,
    bgo#585137, bgo#585592, bgo#585733, bgo#585748, bgo#586566,
    bgo#586568, bgo#587973, bgo#587976, bgo#588744, bgo#588745,
    bgo#589127, bgo#590056, bgo#590622, bgo#579177, bgo#581321,
    bgo#584118, bgo#585433, bgo#585569, bgo#585834, bgo#585960,
    bgo#587052
  + API additions.
* Sun May 17 2009 vuntz@novell.com
- Update to version 0.10.23:
  + Support files > 4GB on Windows
  + Controller interpolation fixes
  + Add timer support to GstPoll and use it for clocking
  + Attempt to typefind contents from the file extension if all
    else fails
  + GStreamer revision control switched to Git
  + Many other bug fixes and improvements
  + Bugs fixed: bgo#579177, bgo#163577, bgo#574160, bgo#575598,
    bgo#575922, bgo#576842, bgo#555978, bgo#565607, bgo#566936,
    bgo#567692, bgo#567725, bgo#568289, bgo#568438, bgo#568481,
    bgo#568632, bgo#568678, bgo#570910, bgo#571227, bgo#571559,
    bgo#572480, bgo#573623, bgo#574024, bgo#574211, bgo#574213,
    bgo#574241, bgo#574484, bgo#574623, bgo#574805, bgo#575695,
    bgo#575814, bgo#576381, bgo#576563, bgo#576582, bgo#577887,
    bgo#577891, bgo#578114, bgo#578201, bgo#579127, bgo#580121,
    bgo#361155, bgo#517231, bgo#572591, bgo#573823, bgo#574163,
    bgo#575682, bgo#575988
  + API additions:
  - New FIXME and MEMDUMP debug levels
  - gst_tag_list_get_buffer() and gst_tag_list_get_buffer_index()
  - New tags: GST_TAG_SUBTITLE_CODEC, GST_TAG_HOMEPAGE
  - gst_util_array_binary_search()
  - gst_message_new_request_state(),
    gst_message_parse_request_state(), GST_MESSAGE_REQUEST_STATE
  - GstPoll::gst_poll_new_timer()
  - GstPoll::gst_poll_write_control()
  - GstPoll::gst_poll_read_control()
* Thu Apr 23 2009 sbrabec@suse.cz
- Don't call autogen in older products.
* Thu Feb  5 2009 vuntz@novell.com
- Update to version 0.10.22:
  + GstController improvements
  + Extensions to the latency setting behaviours
  + Ability for plugins to register dependencies to trigger
    re-scanning
  + Optimisations in some common operations on caps and values and
    elsewhere
  + Add sequence numbers to events so dependent events can be
    associated with
  + the event that caused them
  + New macros for reading and writing float values
  + Many improvements in the basesink base class
  + Support non-default main contexts for GstBus watches
  + Improvements in pull-mode scheduling of sinks
  + Fixes for alignment issues on sparc
  + Ghost pad fixes
  + New bit-reader assistance API
  + Many other bug fixes and improvements
  + Bugs fixed: bgo#567002, bgo#350477, bgo#510354, bgo#526044,
    bgo#539108, bgo#544003, bgo#544293, bgo#545714, bgo#548786,
    bgo#551676, bgo#552778, bgo#553554, bgo#553874, bgo#555196,
    bgo#555307, bgo#555631, bgo#556091, bgo#556900, bgo#557154,
    bgo#557300, bgo#557438, bgo#557649, bgo#559250, bgo#560301,
    bgo#560360, bgo#560399, bgo#560442, bgo#561501, bgo#562170,
    bgo#562949, bgo#564863, bgo#567225, bgo#566393
  + API added:
  - Add bit reader and byte reader classes.
  - gst_message_new_structure_change()
  - gst_message_parse_structure_change()
  - GST_BUFFER_FREE_FUNC()
  - Add GST_READ_UINT24_(LE|BE) and GST_WRITE_UINT24_(LE|BE).
  - GstBaseSrc::gst_base_src_set_blocksize()
  - GstBaseSrc::gst_base_src_get_blocksize()
  - GstBaseSink::gst_base_sink_set_blocksize()
  - GstBaseSink::gst_base_sink_get_blocksize()
  - GstBaseSink::blocksize
  - GstBaseSink::gst_base_sink_do_preroll()
  - Add gst_byte_reader_get_data and gst_byte_reader_peek_data
  - Move float endianness conversion macros from libgstfloatcast to core
  - gst_util_seqnum_next, gst_util_seqnum_compare
  - gst_event_get_seqnum, gst_event_set_seqnum
  - gst_message_get_seqnum, gst_message_set_seqnum
  - GstSeekFlags::GST_SEEK_FLAG_SKIP
  - gst_bin_recalculate_latency()
  - GstBin::do-latency
  - gst_tag_setter_reset_tags()
  - gst_query_new_uri, gst_query_set_uri, gst_query_parse_uri
  - add gst_plugin_add_dependency()
  - add gst_plugin_add_dependency_simple()
- Drop gstreamer-0_10-protect-caps-bnc439323.patch: fixed upstream.
* Thu Nov  6 2008 sbrabec@suse.cz
- Fixed valgrid BuildRequires.
* Fri Oct 31 2008 gburt@suse.de
- Add patch from upstream to fix bad GST_CAPS bug in 0.10.21
    + Fixes bnc#439323 and bgo#555631
* Tue Oct 21 2008 maw@suse.de
- Update to version 0.10.21:
  +  Basetransform rework
  + Basesink synchronisation extensions
  + New documentation
  + Bugs fixed: bgo#481169, bgo#520694, bgo#538201, bgo#544855,
    bgo#339795, bgo#348114, bgo#361718, bgo#533856, bgo#536978,
    bgo#537804, bgo#537812, bgo#538568, bgo#539772, bgo#542175,
    bgo#543444, bgo#543853, bgo#544174, bgo#544776, bgo#545352,
    bgo#545603, bgo#545605, bgo#545607, bgo#545853, bgo#546328,
    bgo#546822, bgo#547277, bgo#547728, bgo#548394, bgo#548652,
    bgo#549504, bgo#551952, bgo#551978, bgo#547835, bgo#538628,
    bgo#546883, and bgo#551509
  + API added:
  * Add GST_TAG_ATTACHMENT for generic file attachments to streams.
  * Add gst_base_sink_set_render_delay()
  * Add gst_base_sink_get_render_delay()
  * Add gst_check_setup_src_pad_by_name
  * Add gst_check_setup_sink_pad_by_name
  * Add gst_check_teardown_pad_by_name
  * Add GstBaseTransform::gst_base_transform_suggest()
  * GstBaseTransform::gst_base_transform_reconfigure()
  * GstPad::gst_pad_set_iterate_internal_links_function()
  * GstPad::GstPadIterIntLinkFunction
  * GstPad::gst_pad_iterate_internal_links()
  * GstPad::gst_pad_iterate_internal_links_default()
  + API deprecated:
  * gst_pad_get_internal_links()
  * gst_pad_set_internal_link_function()
  * gst_pad_get_internal_links_default()
- Add gstreamer-0_10-no-gtk-doc-for-reals.patch.
* Thu Sep  4 2008 mboman@novell.com
- Update to version 0.10.20:
  + Add the Presets interface
  + Use the binary registry by default
  + Deprecate gst_element_get_pad and don't use it anywhere any more.
  + Reverse playback fixes
  + API to get missing element messages from parse_launch parsing.
  + Fixes in latency calculations
  + BaseTransform negotiation fixes
  + New Buffering query and messages
  + Fix multiqueue deadlocks when changing limits
  + Remove pre-generated parser hacks and require newer flex/bison
  + Use GSlice in more places
  + Use static strings in property declarations everywhere to save memory
    allocations
  + Fix unaligned memory accesses with the binary registry and add CRC
    checks
  + Lots of other bug fixes
* Wed May 14 2008 cthiel@suse.de
- fix baselibs.conf
* Tue Apr 29 2008 cthiel@suse.de
- obsolete gstreamer010-<arch> via baselibs.conf
* Tue Apr 15 2008 sbrabec@suse.cz
- fix build
* Mon Apr 14 2008 sbrabec@suse.cz
- Updated to version 0.10.19:
  * Fix a regression in raw fd handling
  * Fixed: bgo#524041
- Fixed Obsoletes (bnc#357153).
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Wed Apr  2 2008 maw@suse.de
- Update to version 0.10.18:
  + New GstPoll abstraction simplifies operations on multiple
    file descriptors
  + Bugs fixed: bgo#516187, bgo#516395, bgo#520756, bgo#498222,
    bgo#499127, bgo#505417, bgo#509559, bgo#510194, bgo#511783,
    bgo#513964, bgo#515469, bgo#519584, bgo#519698, bgo#520152,
    bgo#520671, bgo#520808, bgo#520877, bgo#521740, and bgo#522741.
* Wed Mar 19 2008 maw@suse.de
- Require texlive-latex and texlive-latex-doc to build.
* Tue Feb  5 2008 maw@suse.de
- Update to version 0.10.17:
  + Fix compilation problems
  + Bugs fixed: bgo#512715.
* Tue Feb  5 2008 maw@suse.de
- Update to version 0.10.16:
  + Monotonic/Posix clock support
  + Dumping of dot-file graph descriptions for debugging
  + Cleanup of exported symbols
  + Many bug fixes and enhancements
- Build with -fno-strict-aliasing.
* Tue Jan 22 2008 sbrabec@suse.cz
- Updated to version 0.10.15:
  * Changes for asynchronous sink management
  * New ts-offset property on basesink for adjusting clock synchronisation
  * New GstController LFO feature
  * Fixes and improvements in latency measurement for live pipelines
  * Additional documentation and docs fixes
  * Faster typefinding
  * More tag types added
  * Improvements in various core elements and parent classes
  * New unit tests
  * Allow dumping pipelines as dot graphs
  * GstStructures now support nesting
  * URIHandler interface can now be implemented in bindings
  * Many other bug-fixes and improvements
  * API additions
- Split package according to shared library packaging policy
  (#223286).
* Mon Sep 17 2007 sbrabec@suse.cz
- Updated to version 0.10.14:
  * State change handling improvements
  * New improved GstController API
  * Multi-queue fixes and enhancements
  * Fewer dynamic library relocations
  * Various other fixes and improvements
  * Parallel installability with 0.8.x series
  * Threadsafe design and API
  * Add GstParamSpecFraction, so elements can have fraction
    properties without lots of painful string parsing.
  * Add fail_unless_equals_float() and assert_equals_float()
  * Add gst_type_register_static_full
  * Add gst_element_class_set_details_simple
  * Refactor GstController into the core controller which can take
    a GstControlSource for providing actual values for timestamps.
  * add GST_TAG_LICENSE_URI and GST_TAG_COPYRIGHT_URI
  * gst_element_factory_has_interface()
  * Many bugs fixed.
* Wed Aug 15 2007 coolo@suse.de
- do not require lang package in doc
* Tue Aug  7 2007 maw@suse.de
- Split off a -lang subpackage
- s#%%run_ldconfig#/sbin/ldconfig/ in %%post and %%postun.
* Fri Jul 20 2007 aj@suse.de
- Create separate spec file for doc package.
* Thu Jul 12 2007 dmueller@suse.de
- fix installed headers to be compileable with -pedantic
* Wed Jun 20 2007 sbrabec@suse.cz
- Updated to version 0.10.13:
  * Latency handling infrastructure for live playback scenarios
  * State change handling changes
  * GstController property handling improved
  * Various bug fixes and improvements
  * Parallel installability with 0.8.x series
  * Threadsafe design and API
  * Many bugs fixed
  * Many API additions
* Wed May 16 2007 sbrabec@suse.cz
- Build correctly in older products.
* Sun Apr 22 2007 aj@suse.de
- Cleanup BuildRequires.
* Thu Apr 19 2007 schwab@suse.de
- Fix quoting in autoconf macros.
* Fri Mar 30 2007 aj@suse.de
- Add bison to build requires.
* Tue Mar 27 2007 sbrabec@suse.cz
- Updated to version 0.10.12:
  * API additions
  * Add a warning for improper GLib threading
  * Add support for binary registry serialisation
  * Preliminary support for pull-mode scheduling of entire chains
  * Add support for HPPA
  * Collectpads fixes
  * Lots of bug fixes
- Require check-devel.
* Tue Feb 13 2007 sbrabec@suse.cz
- Do not build unusable static libraries (#238552#c17).
* Mon Dec 18 2006 sbrabec@suse.cz
- Prefix changed to /usr.
- Spec file cleanup.
* Tue Nov 28 2006 sbrabec@suse.cz
- Build correctly in older products.
* Tue Nov  7 2006 abockover@suse.de
- Updated to version 0.10.10:
  * Scores of bug fixes
  * Better non-linear editing
  * Removed GLib 2.6 compatibility
  * Performance improvements on CPUs that support branch hints
  * __gst_debug_min symbol is properly externed
  * Can compile against GStreamer headers in pedantic mode
* Mon Jul 17 2006 danw@suse.de
- Rewrite XXXes to tmp file name before calling mkstemp a second
  time. Fixes the "gst-inspect doesn't work the first time" build bug.
* Fri Jun 16 2006 sbrabec@suse.cz
- Updated to version 0.10.8:
  * Many bug fixes
  * More API additions
  * Fixes for the collectpads helper
  * Support for proper time recording on server-trickmode streams
    via the applied_rate parameter of the NewSegment event
  * QoS in BaseTransform
  * BaseTransform reworked
  * Bus reworked; signal API added
  * Registry cache updating is now done in a fork, so no plugins
    are left opened
  * New version of data protocol now serializes events
* Thu May 25 2006 sbrabec@suse.cz
- Fixed uninitialized variable (#176290).
* Fri Mar 10 2006 jpr@suse.de
-update to version 0.10.4
-Changes since 0.10.3:
  * Parallel installability with 0.8.x series
  * Threadsafe design and API
  * 33%% of library size removed by parse change
  * (Experimental) QoS features (use max-lateness on BaseSink subclasses to enable)
  Bugs fixed since 0.10.3:
  * 323542 : GStreamer 0.10 hangs at EOS for all songs
  * 320340 : triggering a gst_task_join from the streaming task can de...
  * 322628 : document thread-unsafety of gst_value_foo() + gst_value_r...
  * 324186 : Smarter (deterministic!) typefind decisions
  * 324398 : varargs/valist functions aren't bindable
  * 328873 : only one gst_bin_recalc_state allowed at a time
  * 330899 : CVS directory in make dist tarball
  * 330906 : API: add GST_QUERY_TYPE_NAME and GST_MESSAGE_TYPE_NAME
  * 330996 : basesrc emits EOS unconditionally when going to READY
  * 331255 : Shrinking gst_parse_launch bloat
  * 331898 : Basetranform is not reusable
  * 332045 : API: GstPipeline needs API to disable  flushing of its bu...
  * 332277 : [filesrc] seek does not correct read position in non-mmap...
  * 332611 : [basesrc] needs way to prevent expensive start/stop in ch...
  * 332723 : New API: gst_type_find_helper_for_buffer
  * 333042 : New API: gst_type_find_helper_get_range
  * 333266 : Registry file writing rewrite
  * 333272 : tests should set G_SLICE=always-malloc now
  * 333417 : GST_BOILERPLATE_WITH_INTERFACE can't be used in C++ code
  * 333669 : Add pad accessor defines for GstBaseTransform
  * 333779 : New API: add gst_uri_has_protocol
  * 324818 : gst_registry_get_default doesn't sink newly created registry
  * 330125 : _pad_send_event does not check flushing correctly
  * 330684 : Add ability to emit sync-message without messing with the...
* Thu Feb 23 2006 jpr@suse.de
- update version to 0.10.3
- Changes since 0.10.2:
  * Documentation updates
  * Bug fixes
  * Base class improvements
  * Extra utility API
  * More elements ported from 0.8
  * Fixes for win32 build.
* Tue Feb 14 2006 sbrabec@suse.cz
- Do not package never generated registry.xml in /var (#149984).
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jan 18 2006 sbrabec@suse.cz
- Updated to version 0.10.2.
* Tue Jan  3 2006 sbrabec@suse.cz
- Removed unneeded build requirements.
* Tue Jan  3 2006 sbrabec@suse.cz
- Updated to version 0.10.1.
* Tue Dec 13 2005 sbrabec@suse.cz
- Branched gstreamer010 and updated to version 0.10.0.
* Mon Nov 14 2005 sbrabec@suse.cz
- Fixed %%postun error on uninstallation.
* Fri Nov  4 2005 sbrabec@suse.cz
- Call branch-dependent gst-register (#132197).
* Mon Sep  5 2005 sbrabec@suse.cz
- Updated to version 0.8.11.
* Wed Jun  1 2005 sbrabec@suse.cz
- Fixed devel requirements (#72282).
* Thu May 26 2005 sbrabec@suse.cz
- Updated to version 0.8.10.
- Build all documentation.
- Split doc subpackage.
* Wed Mar 16 2005 sbrabec@suse.cz
- Build as user, copying xml.dcl is no more needed.
* Fri Feb 11 2005 gekker@suse.de
- Update to version 0.8.9
* Sat Jan 22 2005 ro@suse.de
- make docu build
* Mon Jan  3 2005 gekker@suse.de
- Update to version 0.8.8
* Tue Dec 21 2004 gekker@suse.de
- Update to version 0.8.7
* Mon Oct 11 2004 sbrabec@suse.cz
- Call gst-register properly (#46870).
* Tue Jun 22 2004 clahey@suse.de
- Fixed gst-register call to be in the right prefix.
* Fri Jun 11 2004 clahey@suse.de
- Don't use --gst-mask argument to gst-register.
* Wed Apr 28 2004 sbrabec@suse.cz
- Updated to version 0.8.1 (GNOME 2.6).
* Sun Mar 28 2004 ro@suse.de
- remove ghostscript-fonts-std from neededforbuild
  use plain ghostscript-mini to build
* Mon Mar 15 2004 sbrabec@suse.cz
- FHS 2.3 fix (mandir, infodir, #35821).
* Fri Feb 13 2004 sbrabec@suse.cz
- Updated to version 0.6.5.
- Build and install docs.
* Sat Jan 10 2004 adrian@suse.de
- use %%run_ldconfig
* Tue Nov  4 2003 ro@suse.de
- build with "-D_GNU_SOURCE" (for posix_memalign)
* Wed Oct 22 2003 sbrabec@suse.cz
- Updated to version 0.6.4.
* Thu Oct 16 2003 schwab@suse.de
- Add atomic ops for ia64.
- Fix warning.
* Wed Oct  8 2003 sbrabec@suse.cz
- Updated to version 0.6.3.
* Thu Sep 18 2003 sbrabec@suse.cz
- Call ldconfig before gst-register in %%post (bug #30675).
* Tue Sep 16 2003 sbrabec@suse.cz
- Call gst-register after installation.
- Added /var items to filelist.
* Mon Jul 14 2003 sbrabec@suse.cz
- GNOME prefix change to /opt/gnome.
* Fri Jun 27 2003 sbrabec@suse.cz
- Updated to version 0.6.2.
- Fixed %%files.
- Fixed directory packaging.
* Tue May 27 2003 ro@suse.de
- remove unpackaged files from buildroot
* Wed Feb  5 2003 meissner@suse.de
- ppc64 is basically ppc, the assembler stub needed is the same.
* Tue Feb  4 2003 sbrabec@suse.cz
- Updated to version 0.6.0.
* Thu Jan 23 2003 sbrabec@suse.cz
- Updated to version 0.5.2.
- FHS fix (localstatedir).
* Fri Jan 17 2003 sbrabec@suse.cz
- Updated to version 0.5.1 (Gnome2).
* Wed Nov 20 2002 ro@suse.de
- fix duplicates in configure.in
* Mon Nov 11 2002 ro@suse.de
- changed neededforbuild <jade_dsl> to <openjade>
* Fri Sep  6 2002 olh@suse.de
- fix build without atomic.h
* Thu Aug 22 2002 hhetter@suse.de
- added a README file and removed the SuSEconfig-script
  ( Bug Id#17620)
* Tue Aug 20 2002 hhetter@suse.de
- use Requires: %%{name} = %%{version} in devel package
- added PreReq: filesystem
* Thu Aug 15 2002 ro@suse.de
- removed gnome-utils from neededforbuild
* Sat Jul 27 2002 adrian@suse.de
- add %%run_ldconfig
* Fri Jul 26 2002 adrian@suse.de
- fix neededforbuld
* Thu Jul  4 2002 ro@suse.de
- neededforbuild quicktime4linux -> libquicktime
* Tue May 21 2002 meissner@suse.de
- %%_lib fixes, various libtool/autoconf/etc. patches.
- started port to x86_64
* Thu Jan 31 2002 ro@suse.de
- changed neededforbuild <libpng> to <libpng-devel-packages>
* Tue Jan 22 2002 ro@suse.de
- changed neededforbuild <kdelibs-artsd> to <kdelibs3-artsd>
* Fri Nov 30 2001 ro@suse.de
- changed neededforbuild <docbktls> to <docbook-toys>
* Wed Nov 28 2001 ro@suse.de
- removed libmpeg2 from neededforbuild
* Mon Nov 19 2001 ro@suse.de
- added new gnome-vfs include path to CFLAGS
- added popt, gconf and oaf to neededforbuild
* Sat Sep  8 2001 egger@suse.de
- Removed LAME due to legal reasons.
* Mon Aug 20 2001 ro@suse.de
- added diffs from cvs to build with current lame and current alsa
* Mon Aug 20 2001 ro@suse.de
- up to 0.2.1 to try to fix compilation
- added kdelibs-artsd to neededforbuild
* Wed Aug  8 2001 ro@suse.de
- changed neededforbuild <sdl> to <SDL>
- changed neededforbuild <sdl-devel> to <SDL-devel>
* Fri Jul 20 2001 kukuk@suse.de
- changed neededforbuild <gs_lib> to <ghostscript-library>
* Wed Jun 27 2001 hhetter@suse.de
- improved documentation support, enabled gtkdoc & docbkutils
* Tue Jun 26 2001 hhetter@suse.de
- added SuSEconfig.gstreamer script
- enabled sdl, libvorbis, ogg, gnome, alsa,
  cdparanoia, aalib and mpeg2 modules
- functionality test in chrooted environment
* Mon Jun 18 2001 hhetter@suse.de
- fixed typo in specfile
* Fri Jun 15 2001 hhetter@suse.de
- update to 0.2.0
- specfile & filelist rework
* Thu Mar 15 2001 hhetter@suse.de
- initial SuSE Package
